#
# Makefile for the micro-mesh firmware
# Supports Msp430 and lpc2148 (arm) architectures.
# (c) 2007 Heiko Will - hwill@inf.fu-berlin.de
#
.PHONY: all clean mspdriver flash cc1100lib

LIBMSPGCC_PATH = /usr/local/lib

MSP_CC = msp430-gcc
MSP_CFLAGS = -O2 -mmcu=msp430x1612 -Wall -fmessage-length=0
MSP_LFLAGS = -mmcu=msp430x1612 -T msp430x1612.x --warn-common 

MSPSRCS :=  $(wildcard src/*.c)
MSPOBJS :=  $(patsubst src/%.c, bin/msp430/%.o, $(MSPSRCS))
MSPDEPS :=  $(patsubst src/%.c, bin/msp430/%.d, $(MSPSRCS))

MSP_DRIVER_OBJS = $(wildcard src/msp430/bin/*.o)

msp : mspdriver $(MSPOBJS)
	$(MSP_CC) $(MSP_LFLAGS) $(MSP_DRIVER_OBJS) $(MSPOBJS) -o bin/msp430/msp430.elf
	msp430-objcopy -O ihex bin/msp430/msp430.elf bin/msp430/msp430.hex
	msp430-size bin/msp430/msp430.elf

-include $(MSPDEPS)

bin/msp430/%.d : src/%.c
	set -e; $(MSP_CC) -MM -I src/driver_api -I src/hal_includes -I src/msp430/includes  $< \
	| sed 's/\($*\)\.o[ :]*/bin\/msp430\/\1.o bin\/msp430\/$*\.d : /g' > $@; \
	[ -s $@ ] || rm -f $@

bin/msp430/%.o : src/%.c
	$(MSP_CC) $(MSP_CFLAGS) -I src/driver_api -I src/hal_includes -I src/msp430/includes  -c $< -o $@

mspdriver:
	make -C src/msp430
 
cc1100lib: msp
	@cp src/msp430/bin/driver_cc1100.o bin/msp430/cc1100lib/
	@cp src/msp430/bin/spi0.o bin/msp430/cc1100lib/ 
	@cp src/hal_includes/driver_cc1100.h bin/msp430/cc1100lib/
	@cp src/hal_includes/smallib.h bin/msp430/cc1100lib/
	@cp src/hal_includes/type.h bin/msp430/cc1100lib/
	@cp bin/msp430/funk.o bin/msp430/cc1100lib/
	@cp bin/msp430/routing.o bin/msp430/cc1100lib/
	@cp bin/msp430/smallib.o bin/msp430/cc1100lib/
	@cp src/funk.h bin/msp430/cc1100lib/
	@cp src/routing.h bin/msp430/cc1100lib/
	@cp bin/msp430/net.o bin/msp430/cc1100lib/
	@cp src/net.h bin/msp430/cc1100lib/
	ar cr bin/msp430/cc1100lib/routing.a bin/msp430/cc1100lib/smallib.o bin/msp430/cc1100lib/driver_cc1100.o bin/msp430/cc1100lib/funk.o bin/msp430/cc1100lib/routing.o bin/msp430/cc1100lib/net.o 
	@rm bin/msp430/cc1100lib/*.o
		
clean:
	@make clean -C src/msp430
	@rm -f bin/msp430/*.o
	@rm -f bin/msp430/*.elf
	@rm -f bin/msp430/*.d

flash:
	LIBMSPGCC_PATH=/usr/local/lib msp430-jtag -m bin/msp430/msp430.hex