/* Copyright (C) 2005, 2006, 2007, 2008 by Thomas Hillebrandt and Heiko Will

This file is part of the Micro-mesh SensorWeb Firmware.

Micro-Mesh is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3, or (at your option)
any later version.

Micro-Mesh is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with Micro-Mesh; see the file COPYING.  If not, write to
the Free Software Foundation, 59 Temple Place - Suite 330,
Boston, MA 02111-1307, USA.  */

#include "config.h"
#ifdef INCLUDE_FAT16
#include <stdlib.h>
#include "cached_reader.h"
#include "type.h"

#define INVALID_SECTOR (0xffffffff)

static cr_io_callback read_cb;
static cr_io_callback write_cb;
static uint32_t cached_sector;
static uint8_t cache_dirty;

uint8_t cr_buffer[512];

int read_counter,cache_miss;

int cr_init(cr_io_callback rcb, cr_io_callback wcb)
{
	cached_sector = INVALID_SECTOR;
	read_cb = rcb;
	write_cb = wcb;
	return 0;	
}

uint8_t *cr_read_sector(uint32_t sector)
{
	read_counter++;
	if (sector != cached_sector)
	{
		if (cr_flush_buffer() != 0)
		{
			return NULL;
		}
		if (read_cb(sector, cr_buffer) != 0)
		{
			return NULL;	
		}
		cache_miss++;
		cached_sector=sector;
	}
	return cr_buffer;	
}

uint8* cr_write_sector(uint32_t sector)
{
	read_counter++;
	if (cached_sector == INVALID_SECTOR)
	{
		cached_sector = sector;
	}	
	else if (sector != cached_sector)
	{
		if (cr_flush_buffer() != 0)
		{
			return NULL;
		}
	}
	cache_dirty = 1;
	return cr_buffer;
}

int cr_flush_buffer(void)
{
	if (cache_dirty)
	{
		if (write_cb(cached_sector, cr_buffer) != 0)
		{
			return -1;
		}
		cache_dirty = 0;
		cache_miss++;
	}
	return 0;
}
#endif
