/* Copyright (C) 2005, 2006, 2007, 2008 by Thomas Hillebrandt and Heiko Will

This file is part of the Micro-mesh SensorWeb Firmware.

Micro-Mesh is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3, or (at your option)
any later version.

Micro-Mesh is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with Micro-Mesh; see the file COPYING.  If not, write to
the Free Software Foundation, 59 Temple Place - Suite 330,
Boston, MA 02111-1307, USA.  */

/* As a special exception, if you include this header file into source
   files compiled by GCC, this header file does not by itself cause
   the resulting executable to be covered by the GNU General Public
   License.  This exception does not however invalidate any other
   reasons why the executable file might be covered by the GNU General
   Public License.  */

#include "config.h"
#ifdef INCLUDE_FAT16
#ifndef DIR_H_
#define DIR_H_
#include "type.h"

#define DIR_ROOTDIR (0xffff)
#define DIR_ATTR_VFAT_NAME 0x0F
#define DIR_ENTRY_IS_FREE  ((char) 0xE5)
#define DIR_END_OF_DIR  ((int)1)
#define DIR_NAME_TERMINATOR	  ((char) 0x20)

typedef struct _dir_handle{
	uint16_t start_cluster;
	uint32_t entry_position;
	uint16_t akt_cluster;
	uint16_t chain_pos;
}dir_handle;

typedef struct _dir_entry{
	char filename[9];
	char extension[4];
	uint32_t filesize;
	union {
		uint8_t asbyte:8;
		struct {
		uint8_t read_only:1;
		uint8_t hidden:1;
		uint8_t system:1;
		uint8_t volume:1;
		uint8_t directory:1;
		uint8_t archive:1;				
		uint8_t unused:2;
		} ;
	} flags;
	date_time create_date;
	uint16_t start_cluster;
}dir_entry;

typedef struct __attribute__ ((packed)) _raw_dir_entry{
	char filename[8];
	char extension[3];	
	union {
		uint8_t asbyte:8;
		struct {
		uint8_t read_only:1;
		uint8_t hidden:1;
		uint8_t system:1;
		uint8_t volume:1;
		uint8_t directory:1;
		uint8_t archive:1;				
		uint8_t unused:2;
		};
	} flags;
	uint8_t reserved[10];
	uint16_t time;
	uint16_t date;
	uint16_t cluster;
	uint32_t filesize;
}	raw_dir_entry;

// Opens a directory
extern int dir_opendir(dir_handle *dir,const char *path);

// Returns the next entry of a directory
extern int dir_readdir(dir_handle *handle,dir_entry *res);

// Writes an entry to the directory
extern int dir_write_entry(dir_handle *handle, raw_dir_entry *newentry);

// Reads a specific raw-entry of a directory
extern raw_dir_entry *dir_readdir_raw(dir_handle *handle);

#endif /*DIR_H_*/
#endif
