#ifndef DRIVERS_H_
#define DRIVERS_H_
#include <stdint.h>

typedef struct driver driver;

typedef void (*driver_cb_t)(driver*);
typedef int (*driver_cb_get_t)(driver*);
typedef int (*driver_cb_put_t)(driver*,int);
typedef void (*driver_cb_cin_t)(driver*,int);
typedef int (*driver_cb_blkw_t)(driver*,char*,uint16_t);


struct driver
{
	uint8_t active :1;
	uint8_t awake :1;
	uint8_t extended :1;
	driver_cb_t init;
};

typedef struct 
{
	driver base;
	unsigned int* port;
	uint8_t pin :7;
	uint8_t direction:1;
}driver_iopin;

typedef struct extended_driver extended_driver;

struct extended_driver{
	driver base;
	driver *deps;
	driver_cb_t awake;
	driver_cb_t suspend;
	driver_cb_t activate;
	driver_cb_t deactivate;	
	uint8_t depcount;
};

typedef struct driver_serial
{
	extended_driver driver;
	uint32_t baudrate:24;
	driver_cb_cin_t char_in;
	void* char_in_ref;
	driver_cb_cin_t put_char;
}driver_serial;



typedef struct driver_spi
{
	extended_driver driver;
	driver_cb_get_t get_char;
	driver_cb_cin_t put_char;
	driver_cb_blkw_t read;
	driver_cb_blkw_t write;
	uint32_t speed;
	driver_iopin *csel;
	char bitwidth;
}driver_spi;

#endif /*DRIVERS_H_*/
