/* Copyright (C) 2005, 2006, 2007, 2008 by Thomas Hillebrandt and Heiko Will

This file is part of the Micro-mesh SensorWeb Firmware.

Micro-Mesh is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3, or (at your option)
any later version.

Micro-Mesh is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with Micro-Mesh; see the file COPYING.  If not, write to
the Free Software Foundation, 59 Temple Place - Suite 330,
Boston, MA 02111-1307, USA.  */

#include "config.h"
#ifdef INCLUDE_DISPLAY
/*
    created with FontEditor written by H. Reddmann
    HaReddmann at t-online dot de

    File Name           : f9x14.h
    Date                : 1.10.2004
    Font size in bytes  : 0x05FE, 1534
    Font width          : 9
    Font height         : 14
    Font first char     : 0x20
    Font last char      : 0xFC
    Font bits per pixel : 1
    Font is compressed  : false

    The font data are defined as

    struct _FONT_ {
     // common shared fields
       uint16_t    font_Size_in_Bytes_over_all_included_Size_it_self;
       uint8_t     font_Width_in_Pixel_for_fixed_drawing;
       uint8_t     font_Height_in_Pixel_for_all_Characters;
       uint8_t     font_Bits_per_Pixels;
                    // if MSB are set then font is a compressed font
       uint8_t     font_First_Char;
       uint8_t     font_Last_Char;
       uint8_t     font_Char_Widths[font_Last_Char - font_First_Char +1];
                    // for each character the separate width in pixels,
                    // characters < 128 have an implicit virtual right empty row
                    // characters with font_Char_Widths[] == 0 are undefined

     // if compressed font then additional fields
       uint8_t     font_Byte_Padding;
                    // each Char in the table are aligned in size to this value
       uint8_t     font_RLE_Table[3];
                    // Run Length Encoding Table for compression
       uint8_t     font_Char_Size_in_Bytes[font_Last_Char - font_First_Char +1];
                    // for each char the size in (bytes / font_Byte_Padding) are stored,
                    // this get us the table to seek to the right beginning of each char
                    // in the font_data[].

     // for compressed and uncompressed fonts
       uint8_t     font_data[];
                    // bit field of all characters
    }
*/


#include "f9x14.h"

const uint8_t smallNumbers[] = {
    0x00, 0x2A, 0x04, 0x05, 0x01, 0x2C, 0x39, 0x01, 0x00, 0x02, 0x00, 0x03, 0x03, 0x03, 0x03, 0x03,
    0x03, 0x03, 0x03, 0x03, 0x03, 0x18, 0xE3, 0x1F, 0xBF, 0x10, 0x5F, 0x57, 0x59, 0xAB, 0x32, 0x9D,
    0xDC, 0x9A, 0x98, 0x4D, 0xB9, 0x0C, 0x55, 0x95, 0xAC, 0x0E
};


// Zahlen 1 - 4
const uint8_t bigNumbers[] = {
    0x04, 0x3A, 0x3E, 0x57, 0x81, 0x30, 0x34,
    0x39, 0x20, 0x38, 0x39, 0x3D, 
    0x02, 0x03, 0x0B, 0x1F, 
    0x68, 0x29, 0x8C, 0x8F, 0x66, 
    0x83, 0x3D, 0x29, 0xC0, 0x4B, 0x4E, 0x01, 0xEE, 0x2E, 0x01, 0xEE, 0xB6, 0xCB, 0xED, 0x4A, 0xC9, 
    0xED, 0x96, 0x94, 0xF2, 0x93, 0x4A, 0x82, 0xBF, 0xA4, 0x12, 0xE0, 0x6F, 0x49, 0x05, 0xF8, 0xDB, 
    0x52, 0xF9, 0x4D, 0xC1, 0x2E, 0x25, 0xD8, 0xA5, 0xDC, 0x96, 0x0B, 0xE0, 0xB6, 0x49, 0xDC, 0x72, 
    0x02, 0xDC, 0x26, 0x80, 0xCB, 0x29, 0x81, 0x4B, 0x26, 0xEE, 0x24, 0x37, 0x80, 0x3B, 0x09, 0x70, 
    0x03, 0x73, 0x52, 0x00, 0x93, 0x81, 0x39, 0x29, 0x31, 0x63, 0x4E, 0x4A, 0x00, 0x13, 0xF0, 0x06, 
    0x03, 0xDE, 0x60, 0xA0, 0x2D, 0xB7, 0xB4, 0x25, 0xBC, 0xC5, 0x6D, 0xB9, 0x05, 0x6E, 0xCB, 0x2D, 
    0x80, 0xDB, 0x6E, 0x01, 0xDC, 0x76, 0x0B, 0xE0, 0xB6, 0x5B, 0x00, 0xB7, 0xDD, 0x02, 0xB8, 0xED, 
    0x16, 0xC0, 0x6D, 0xB7, 0x00, 0x6E, 0xCB, 0x2D, 0xF6, 0x16, 0xA3, 0x2D, 0xB7, 0xB4, 0x25, 0xE0, 
    0x0D, 0x06, 0xBC, 0xC1, 0x80, 0x39, 0x29, 0x01, 0xCC, 0x98, 0x93, 0x12, 0x33, 0x30, 0x39, 0x29, 
    0x30, 0x19, 0xB8, 0x93, 0x00, 0x37, 0x80, 0x3B, 0xC9, 0x4D, 0xE0, 0x72, 0x4A, 0xE0, 0x92, 0x09, 
    0xDC, 0x72, 0x82, 0x5B, 0x26, 0x71, 0xDB, 0x25, 0x6E, 0x2B, 0xBB, 0x94, 0x60, 0x97, 0x02, 0x7E, 
    0x2B, 0xF8, 0xDB, 0x2A, 0xF9, 0x5B, 0x2A, 0x01, 0xFE, 0x92, 0xD2, 0x4F, 0x29, 0xB8, 0xDD, 0x52, 
    0x4A, 0x70, 0x9B, 0x5C, 0xEE, 0xB6, 0x4B, 0x80, 0xBB, 0x53, 0xF0, 0x76, 0x52, 0x60, 0x73, 0x00, 
    0x4A, 0x82, 0xB6, 0xDC, 0x14, 0xB4, 0xE5, 0xA6, 0x78, 0x53, 0xDA, 0x72, 0x53, 0xBC, 0x29, 0x6D, 
    0xB9, 0x29, 0xDE, 0x04, 0x78, 0x53, 0xBC, 0x09, 0xF0, 0x26, 0xC0, 0xDC, 0x04, 0x78, 0x13, 0xE0, 
    0x4D, 0x80, 0xB9, 0x09, 0xE6, 0x26, 0x98, 0x9B, 0x00, 0x73, 0x13, 0xCC, 0x4D, 0x30, 0x37, 0xC1, 
    0xDC, 0x64, 0x72, 0xD3, 0xEF, 0x96, 0x0C, 0xF0, 0xBB, 0x6D, 0x7E, 0x1B, 0xF8, 0x6D, 0xE2, 0xB7, 
    0x49, 0xFC, 0x36, 0x89, 0xDF, 0x26, 0xF1, 0xDB, 0x24, 0x7E, 0x9B, 0xC4, 0x6F, 0x93, 0xF8, 0x6D, 
    0x12, 0x00, 0x9B, 0x12, 0xA0, 0xA4, 0x92, 0xA0, 0x9C, 0xD4, 0x56, 0x09, 0x5A, 0x4E, 0x49, 0xAC, 
    0xA0, 0x2D, 0xA7, 0x04, 0x26, 0x05, 0x98, 0x53, 0x00, 0x97, 0x72, 0xA7, 0xB8, 0x4D, 0x02, 0x97, 
    0x9C, 0xE0, 0x96, 0x49, 0xDC, 0x4E, 0x6E, 0xC9, 0x04, 0x70, 0xCB, 0x25, 0x71, 0x5B, 0x26, 0x70, 
    0x4B, 0x2E, 0x01, 0xEC, 0xC4, 0x6D, 0x97, 0xC0, 0x66, 0x00, 0xB7, 0xE5, 0x12, 0x9B, 0x0C, 0xE0, 
    0x76, 0x49, 0xEC, 0x06, 0x2E, 0x27, 0xBB, 0x0C, 0x4C, 0x4E, 0x70, 0x09, 0xC7, 0xE4, 0x04, 0x97, 
    0x80, 0x63, 0x4E, 0x70, 0x19, 0xC7, 0x13, 0xE0, 0x06, 0x06, 0x3C, 0x01, 0x6E, 0x00, 0x03, 0x9E, 
    0xE0, 0x26, 0x06, 0xDA, 0x72, 0x82, 0x9B, 0xC0, 0x40, 0x5B, 0x4E, 0x6E, 0x02, 0x18, 0x5E, 0x12, 
    0xB8, 0x49, 0x8C, 0xB6, 0x9C, 0x4C, 0x26, 0x81, 0xD1, 0x96, 0x4B, 0x02, 0x37, 0x09, 0x8C, 0xB6, 
    0x5C, 0x12, 0x57, 0x46, 0x5B, 0x2E, 0x01, 0x5C, 0xC1, 0x68, 0xCB, 0x25, 0x70, 0x05, 0x18, 0x6D, 
    0xB9, 0xC4, 0x55, 0x8C, 0xB6, 0x5C, 0x00, 0x57, 0x81, 0xD1, 0x96, 0x0B, 0x5C, 0x2A, 0x30, 0xDA, 
    0x72, 0x71, 0xA9, 0x00, 0x46, 0x5B, 0x0E, 0x70, 0xA9, 0xC4, 0xF0, 0x5C, 0x2A, 0x81, 0x61, 0x29, 
    0x01, 0x5C, 0x2A, 0x01, 0x0C, 0xB4, 0xA5, 0x94, 0xC0, 0xA5, 0x92, 0x18, 0xB0, 0x14, 0xC0, 0xA5, 
    0x92, 0xC0, 0x80, 0xA5, 0xC0, 0xA5, 0x64, 0xC0, 0x94, 0x00, 0x97, 0x94, 0x1C, 0x53, 0x72, 0x49, 
    0x09, 0x8E, 0x49, 0x25, 0x80, 0x5B, 0x09, 0x70, 0x60, 0x52, 0x89, 0x5B, 0x29, 0x0E, 0x5C, 0x0A, 
    0x70, 0x4B, 0x29, 0x70, 0x00, 0x97, 0x4C, 0x00, 0xB7, 0x95, 0x02, 0x38, 0xC0, 0x4D, 0x29, 0x71, 
    0xF2, 0xB6, 0x94, 0x12, 0x38, 0xC1, 0x5B, 0xCE, 0x09, 0xDE, 0x0E, 0x4E, 0x80, 0x97, 0x03, 0x9C, 
    0x04, 0x5F, 0x60, 0xD9, 0x2D, 0x17, 0xC0, 0x82, 0x5D, 0x2E, 0x81, 0x15, 0x7B, 0x49, 0xAC, 0x00, 
    0x6E, 0x39, 0x59, 0x49, 0xDA, 0x72, 0x0A, 0xBC, 0x29, 0x06, 0x1B, 0xBA, 0x24, 0x20, 0x97, 0x04, 
    0x2D, 0x07, 0xB4, 0x4B, 0x82, 0xB6, 0x52, 0x82, 0x96, 0x5C, 0x12, 0x58, 0x4A, 0x5B, 0x2E, 0x09, 
    0x4C, 0x4A, 0x5E, 0x12, 0x97, 0x4A, 0x00, 0x77, 0x09, 0xE0, 0x92, 0x4A, 0x5C, 0x2E, 0x01, 0xDC, 
    0x2A, 0x70, 0xC9, 0x25, 0x80, 0x5B, 0x0A, 0x70, 0xBB, 0x04, 0x70, 0x4B, 0xCA, 0x2D, 0x97, 0x00, 
    0x6E, 0x9B, 0xC4, 0x2D, 0xB9, 0x24, 0x70, 0xCB, 0x24, 0x6E, 0xA7, 0xC0, 0x25, 0x13, 0xB8, 0x9C, 
    0x92, 0xB8, 0x4C, 0x4C, 0x4E, 0x02, 0x4C, 0x06, 0x30, 0x39, 0x29, 0x30, 0x19, 0x98, 0x93, 0x12, 
    0x33, 0xE6, 0xA4, 0x04, 0x70, 0xBC, 0xC1, 0x80, 0x37, 0x18, 0x68, 0xCB, 0x2D, 0x6D, 0x09, 0x0F, 
    0xE0, 0xDA, 0x12, 0x96, 0xD2, 0x76, 0x6E, 0x4B, 0x29, 0x6D, 0x39, 0xB8, 0xAD, 0x94, 0xB6, 0x03, 
    0xDC, 0x56, 0x4A, 0xDB, 0x01, 0x6E, 0x2B, 0xA5, 0xED, 0x00, 0xB7, 0x95, 0xD2, 0x76, 0x80, 0xDB, 
    0x4A, 0x69, 0x3B, 0xC0, 0x6D, 0xA5, 0xB4, 0x1D, 0xE0, 0xB6, 0x12, 0xD0, 0x96, 0x03, 0xDC, 0x56, 
    0x02, 0xDA, 0x72, 0x40, 0x5B, 0xA2, 0x2D, 0x25, 0xB4, 0xE5, 0x80, 0xB6, 0x44, 0x5B, 0x4A, 0x1E, 
    0x0C, 0x2B, 0x09, 0xCC, 0xB5, 0x25, 0x60, 0x25, 0x31, 0xB9, 0xB6, 0x8C, 0x95, 0xC0, 0x95, 0x12, 
    0xC0, 0x31, 0x95, 0xB8, 0x94, 0x12, 0x38, 0x26, 0x15, 0xB8, 0xA4, 0x94, 0x38, 0x80, 0x49, 0xC1, 
    0x2D, 0x29, 0x05, 0x66, 0x00, 0x97, 0x4C, 0x60, 0x4B, 0x31, 0x93, 0x17, 0x6D, 0x29, 0xC1, 0x4C, 
    0x70, 0x12, 0xB0, 0x92, 0xB8, 0x09, 0x70, 0xC6, 0x4A, 0xE0, 0x26, 0x81, 0xDD, 0x92, 0x81, 0x49, 
    0xC5, 0xA5, 0x60, 0xB7, 0x89, 0xCB, 0x04, 0x70, 0x4B, 0x01, 0x76, 0xC9, 0xE4, 0x6D, 0x15, 0xD8, 
    0x4D, 0x80, 0xB7, 0x54, 0x62, 0x27, 0xC1, 0x5B, 0x25, 0x71, 0x4B, 0x0A, 0x2F, 0x25, 0xB8, 0x54, 
    0x70, 0x52, 0x0A, 0xD0, 0x56, 0x09, 0xF0, 0x49, 0x81, 0xDD, 0x72, 0x52, 0x62, 0x97, 0x1B, 0xEC, 
    0x2D, 0x80, 0x5B, 0x6E, 0x6A, 0x4B, 0x09, 0x00, 0x93, 0xCC, 0x4D, 0x30, 0xB9, 0xC9, 0xDD, 0x92, 
    0xC0, 0xE5, 0x96, 0x00, 0x6E, 0xB7, 0x04, 0x6E, 0xB9, 0x25, 0x6E, 0xC9, 0x2D, 0x80, 0xDB, 0x6E, 
    0xB1, 0x37, 0xC0, 0xE6, 0x06, 0x9B, 0x9C, 0x94, 0x00, 0x76, 0x39, 0x29, 0x81, 0x5D, 0x72, 0x52, 
    0x62, 0xB7, 0x93, 0x02, 0xB8, 0x85, 0x27, 0xC5, 0x2D, 0x01, 0x4F, 0x02, 0xDC, 0x32, 0x9E, 0x04, 
    0xB7, 0x01, 0x3C, 0xC9, 0x6D, 0xE2, 0x29, 0x89, 0x5B, 0x26, 0xF0, 0x94, 0x00, 0x6E, 0x93, 0x78, 
    0x4A, 0xE0, 0x36, 0x09, 0x3C, 0x25, 0x6E, 0xE5, 0x29, 0x70, 0x4B, 0xC1, 0x53, 0xDC, 0x2A, 0x9E, 
    0x00, 0xB7, 0x0A, 0x3C, 0xC1, 0xAD, 0x02, 0x78, 0x49, 0xE0, 0x96, 0x4A, 0xBC, 0x24, 0x6E, 0x95, 
    0x00, 0x5E, 0x02, 0xB8, 0x55, 0x12, 0x2F, 0x81, 0x5B, 0x25, 0x81, 0x17, 0xC0, 0x2D, 0x25, 0x2F, 
    0x70, 0x2B, 0x01, 0x5E, 0xDC, 0x4A, 0xF1, 0xE0, 0x96, 0x52, 0xE0, 0xB9, 0xA5, 0x14, 0xC0, 0x52, 
    0x02, 0xB8, 0x95, 0x12, 0x58, 0x4A, 0xE0, 0x56, 0x4A, 0x00, 0x4B, 0x01, 0xDC, 0x72, 0x96, 0x82, 
    0xDF, 0x6D, 0x83, 0xDF, 0x6D, 0x99, 0xDF, 0x06, 0x7E, 0x9B, 0xC0, 0x6F, 0x13, 0xF8, 0x6D, 0x02, 
    0xBF, 0x4D, 0xE0, 0xB7, 0x09, 0xFC, 0x36, 0x81, 0xDF, 0x26, 0xF0, 0xDB, 0x9C, 0x04, 0x78, 0x53, 
    0xBC, 0x29, 0xDE, 0x14, 0x6F, 0x8A, 0x37, 0xC5, 0x9B, 0xE2, 0x4D, 0xF1, 0xA6, 0x78, 0x53, 0xBC, 
    0x29, 0x96, 0x00, 0x00, 0x00
};


const uint8_t f9x14[] = {
    0x06, 0x06, 0x09, 0x0E, 0x01, 0x20, 0xFC,
    0x04, 0x02, 0x05, 0x08, 0x07, 0x07, 0x07, 0x02, 0x04, 0x04, 0x05, 0x05, 0x02, 0x05, 0x02, 0x06, 
    0x07, 0x06, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x02, 0x02, 0x06, 0x06, 0x06, 0x05, 
    0x08, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x08, 0x08, 0x04, 0x06, 0x07, 0x07, 0x08, 0x08, 0x08, 
    0x07, 0x08, 0x08, 0x07, 0x08, 0x08, 0x07, 0x08, 0x07, 0x08, 0x06, 0x03, 0x06, 0x03, 0x08, 0x08, 
    0x03, 0x06, 0x06, 0x06, 0x06, 0x06, 0x05, 0x06, 0x06, 0x02, 0x04, 0x07, 0x02, 0x08, 0x06, 0x06, 
    0x06, 0x06, 0x05, 0x05, 0x05, 0x06, 0x06, 0x07, 0x06, 0x06, 0x05, 0x05, 0x02, 0x05, 0x08, 0x00, 
    0x08, 0x00, 0x03, 0x00, 0x06, 0x00, 0x00, 0x00, 0x06, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
    0x00, 0x03, 0x03, 0x05, 0x05, 0x07, 0x00, 0x00, 0x06, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x03, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
    0x04, 0x06, 0x06, 0x06, 0x00, 0x07, 0x08, 0x00, 0x00, 0x07, 0x07, 0x00, 0x00, 0x00, 0x00, 0x00, 
    0x00, 0x00, 0x00, 0x00, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x06, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00, 0x00, 0x08, 
    0x00, 0x00, 0x00, 0x00, 0x07, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x07, 0x07, 0x07, 0x00, 0x00, 0x00, 0x07, 
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xF8, 0x0D, 0x7E, 0xC3, 0x01, 0x70, 0x00, 0x00, 0x00, 
    0x07, 0xC0, 0x01, 0x00, 0x0C, 0x60, 0x0F, 0xF8, 0x80, 0x37, 0x80, 0x3D, 0xE0, 0x03, 0xDE, 0x00, 
    0x06, 0x80, 0x13, 0xF0, 0x09, 0x64, 0xC2, 0xFF, 0x43, 0x26, 0x90, 0x0F, 0xC8, 0xF1, 0xC0, 0x24, 
    0x3C, 0xCF, 0x03, 0x3C, 0xC0, 0xF3, 0x3C, 0x24, 0x03, 0x0F, 0xDC, 0x81, 0xFF, 0x20, 0x22, 0xF8, 
    0x09, 0xDC, 0x02, 0x60, 0x00, 0x34, 0x1C, 0x00, 0x07, 0x00, 0x7E, 0xE0, 0x7F, 0x1C, 0x38, 0x01, 
    0x48, 0x00, 0x72, 0xE0, 0xF8, 0x1F, 0xF8, 0x01, 0x12, 0x00, 0x03, 0xF0, 0x03, 0x30, 0x00, 0x12, 
    0x00, 0x02, 0x80, 0x00, 0xF8, 0x00, 0x08, 0x00, 0x02, 0x00, 0x3C, 0x00, 0x07, 0x08, 0x00, 0x02, 
    0x80, 0x00, 0x20, 0x00, 0x08, 0x00, 0x30, 0x00, 0x0C, 0x00, 0x0C, 0xE0, 0x03, 0x3E, 0xF0, 0x01, 
    0x1F, 0xC0, 0x00, 0xC0, 0x1F, 0xF8, 0x0F, 0x82, 0x82, 0x9C, 0xA0, 0x20, 0xF8, 0x0F, 0xFC, 0x01, 
    0x81, 0x40, 0x20, 0xF8, 0x0F, 0xFE, 0x03, 0x80, 0x00, 0x20, 0x10, 0x08, 0x06, 0x83, 0xE0, 0x20, 
    0x2C, 0x88, 0x09, 0x3E, 0x02, 0x87, 0x40, 0x10, 0x18, 0x0C, 0x22, 0x82, 0x88, 0x20, 0x22, 0xF8, 
    0x0F, 0xDC, 0x01, 0x30, 0x00, 0x0A, 0x60, 0x02, 0x84, 0x80, 0xFF, 0xE0, 0x3F, 0x00, 0x02, 0x00, 
    0x81, 0xC7, 0xE0, 0x21, 0x48, 0x08, 0x12, 0x82, 0xFC, 0x20, 0x1E, 0xE0, 0x07, 0xFC, 0x83, 0x85, 
    0x20, 0x21, 0x48, 0x08, 0xF2, 0x03, 0x78, 0x20, 0x00, 0x08, 0x08, 0x82, 0x83, 0x78, 0xA0, 0x07, 
    0x78, 0x00, 0x06, 0x00, 0x77, 0xE0, 0x3F, 0x88, 0x08, 0x22, 0x82, 0x88, 0xE0, 0x3F, 0x70, 0x07, 
    0x3C, 0x80, 0x9F, 0x20, 0x24, 0x08, 0x09, 0x42, 0x83, 0x7F, 0xC0, 0x0F, 0x60, 0x0C, 0x18, 0x03, 
    0xC6, 0x83, 0x71, 0x80, 0x01, 0x60, 0x00, 0x24, 0x00, 0x09, 0x20, 0x04, 0x08, 0x01, 0x24, 0x00, 
    0x09, 0x40, 0x02, 0x90, 0x00, 0x24, 0x00, 0x09, 0x20, 0x04, 0x08, 0x01, 0x24, 0x00, 0x09, 0x80, 
    0x01, 0x60, 0x00, 0x01, 0x20, 0x36, 0xC8, 0x0D, 0x1E, 0x00, 0x03, 0x00, 0x1F, 0x20, 0x08, 0xE4, 
    0x04, 0x45, 0x41, 0x51, 0x90, 0x13, 0x08, 0x01, 0x3C, 0x00, 0x38, 0xE0, 0x0F, 0xFE, 0x80, 0x21, 
    0xE0, 0x0F, 0xE0, 0x0F, 0x80, 0x83, 0xFF, 0xE0, 0x3F, 0x88, 0x08, 0x22, 0x82, 0x8F, 0xC0, 0x3F, 
    0x00, 0x07, 0xF8, 0x00, 0x7F, 0x60, 0x30, 0x08, 0x08, 0x02, 0x82, 0x80, 0x40, 0x10, 0xF8, 0x0F, 
    0xFE, 0x83, 0x80, 0x20, 0x20, 0x18, 0x0C, 0xFC, 0x01, 0x3E, 0xE0, 0x3F, 0xF8, 0x0F, 0x22, 0x82, 
    0x88, 0x20, 0x22, 0x08, 0x08, 0x02, 0x82, 0xFF, 0xE0, 0x3F, 0x88, 0x00, 0x22, 0x80, 0x08, 0x20, 
    0x00, 0x08, 0x00, 0xF8, 0x00, 0x7F, 0x60, 0x30, 0x08, 0x08, 0x42, 0x82, 0x90, 0x20, 0x3C, 0x10, 
    0x0F, 0xFE, 0x83, 0xFF, 0x00, 0x02, 0x80, 0x00, 0x20, 0x00, 0x08, 0xE0, 0x3F, 0xF8, 0x0F, 0x02, 
    0x82, 0xFF, 0xE0, 0x3F, 0x08, 0x08, 0x00, 0x82, 0x80, 0x20, 0x20, 0x08, 0x08, 0xFE, 0x83, 0x7F, 
    0xE0, 0x3F, 0xF8, 0x0F, 0x70, 0x00, 0x36, 0xC0, 0x18, 0x18, 0x0C, 0x02, 0x82, 0xFF, 0xE0, 0x3F, 
    0x00, 0x08, 0x00, 0x02, 0x80, 0x00, 0x20, 0x00, 0x08, 0xFE, 0x83, 0xFF, 0xC0, 0x03, 0xE0, 0x03, 
    0xF8, 0x00, 0x0F, 0xE0, 0x3F, 0xF8, 0x0F, 0xFE, 0x83, 0xFF, 0xC0, 0x01, 0xE0, 0x01, 0xF0, 0x00, 
    0x70, 0xE0, 0x3F, 0xF8, 0x0F, 0xF8, 0x00, 0x7F, 0x60, 0x30, 0x08, 0x08, 0x02, 0x82, 0xC1, 0xC0, 
    0x1F, 0xE0, 0x03, 0xFE, 0x83, 0xFF, 0x20, 0x04, 0x08, 0x01, 0x42, 0x80, 0x1F, 0xC0, 0x03, 0xE0, 
    0x03, 0xFC, 0x81, 0xC1, 0x20, 0x20, 0x08, 0x0E, 0x86, 0x07, 0xFF, 0x81, 0x4F, 0xF8, 0x0F, 0xFE, 
    0x83, 0x08, 0x20, 0x06, 0x88, 0x03, 0xBE, 0x01, 0xC7, 0x00, 0x20, 0x70, 0x04, 0x3E, 0x82, 0x8C, 
    0x20, 0x22, 0x88, 0x09, 0xE2, 0x03, 0x71, 0x20, 0x00, 0x08, 0x00, 0x02, 0x80, 0xFF, 0xE0, 0x3F, 
    0x08, 0x00, 0x02, 0x80, 0x00, 0xE0, 0x1F, 0xF8, 0x0F, 0x00, 0x02, 0x80, 0x00, 0x20, 0x00, 0x08, 
    0xFE, 0x83, 0x7F, 0xE0, 0x00, 0xF8, 0x01, 0xF0, 0x03, 0xE0, 0x00, 0x3F, 0xF8, 0x01, 0x0E, 0x80, 
    0xFF, 0xE0, 0x3F, 0x80, 0x03, 0x3E, 0x80, 0x0F, 0x00, 0x0E, 0xF8, 0x0F, 0xFE, 0x83, 0xC1, 0xE0, 
    0x38, 0xE0, 0x03, 0x70, 0x00, 0x3E, 0xE0, 0x38, 0x18, 0x0C, 0x06, 0x80, 0x03, 0x80, 0x01, 0xC0, 
    0x0F, 0xF0, 0x03, 0x06, 0xE0, 0x00, 0x18, 0x00, 0x02, 0x83, 0xF0, 0x20, 0x2F, 0xF8, 0x08, 0x0E, 
    0x82, 0x80, 0xF0, 0xFF, 0xFC, 0x3F, 0x01, 0xC8, 0x00, 0xF0, 0x01, 0xF0, 0x01, 0xE0, 0x03, 0xE0, 
    0x03, 0xC0, 0x04, 0x20, 0xFF, 0xCF, 0xFF, 0x03, 0x01, 0x60, 0x00, 0x0C, 0x80, 0x01, 0x60, 0x00, 
    0x30, 0x00, 0x18, 0x00, 0x04, 0x00, 0x80, 0x00, 0x20, 0x00, 0x08, 0x00, 0x02, 0x80, 0x00, 0x20, 
    0x00, 0x08, 0x00, 0x12, 0x00, 0x0C, 0x00, 0x02, 0x00, 0x70, 0x80, 0x3E, 0xA0, 0x08, 0x28, 0x02, 
    0xFE, 0x00, 0x3F, 0xFC, 0x0F, 0xFF, 0x03, 0x82, 0x80, 0x20, 0xE0, 0x0F, 0xF0, 0x01, 0x7C, 0x80, 
    0x3F, 0x20, 0x08, 0x08, 0x02, 0x82, 0x00, 0x11, 0xC0, 0x07, 0xF8, 0x03, 0x82, 0x80, 0x20, 0xFC, 
    0x0F, 0xFF, 0x03, 0x7C, 0x80, 0x3F, 0x20, 0x09, 0x48, 0x02, 0x9E, 0x00, 0x17, 0x20, 0x00, 0xFE, 
    0xC3, 0xFF, 0x90, 0x00, 0x24, 0x00, 0xF0, 0x01, 0xFE, 0x82, 0xA0, 0x20, 0x28, 0xF8, 0x0F, 0xFE, 
    0xF1, 0x3F, 0xFC, 0x0F, 0x08, 0x00, 0x02, 0x80, 0x3F, 0xC0, 0x0F, 0xFB, 0xC3, 0xFE, 0x00, 0x80, 
    0x20, 0x20, 0xFB, 0xCF, 0xFE, 0xF1, 0x3F, 0xFC, 0x0F, 0x60, 0x00, 0x3C, 0x80, 0x19, 0x20, 0x0C, 
    0x00, 0xC2, 0xFF, 0xF0, 0x3F, 0xE0, 0x0F, 0xF0, 0x03, 0x02, 0x80, 0x3F, 0xC0, 0x0F, 0x08, 0x00, 
    0xFE, 0x00, 0x3F, 0xE0, 0x0F, 0xF8, 0x03, 0x02, 0x80, 0x00, 0xE0, 0x0F, 0xF0, 0x03, 0x7C, 0x80, 
    0x3F, 0x20, 0x08, 0x08, 0x02, 0xFE, 0x00, 0x1F, 0xE0, 0x3F, 0xF8, 0x0F, 0x82, 0x80, 0x20, 0xE0, 
    0x0F, 0xF0, 0x01, 0x7C, 0x80, 0x3F, 0x20, 0x08, 0x08, 0x02, 0xFE, 0x83, 0xFF, 0xE0, 0x0F, 0xF8, 
    0x03, 0x04, 0x80, 0x01, 0x60, 0x00, 0x30, 0x02, 0x9E, 0x80, 0x24, 0x20, 0x0F, 0x88, 0x01, 0x02, 
    0xE0, 0x1F, 0xF8, 0x0F, 0x08, 0x02, 0x82, 0x80, 0x1F, 0xE0, 0x0F, 0x00, 0x02, 0x80, 0x80, 0x3F, 
    0xE0, 0x0F, 0x38, 0x00, 0x7E, 0x00, 0x3C, 0x00, 0x0F, 0xF8, 0x01, 0x0E, 0x80, 0x3F, 0xE0, 0x07, 
    0xC0, 0x00, 0x1E, 0x00, 0x0C, 0xE0, 0x07, 0xF8, 0x03, 0xC6, 0x80, 0x3B, 0x80, 0x03, 0xE0, 0x00, 
    0xEE, 0x80, 0x31, 0xE0, 0x00, 0xF8, 0x09, 0xF0, 0x03, 0x7C, 0xE0, 0x07, 0x38, 0x00, 0xC2, 0x80, 
    0x3C, 0xA0, 0x0B, 0x78, 0x02, 0x86, 0x00, 0x02, 0xF8, 0x1F, 0xDF, 0x4F, 0x00, 0x12, 0x80, 0xFC, 
    0x3F, 0xFF, 0x4F, 0x00, 0x12, 0x80, 0x7C, 0x3F, 0xFE, 0x07, 0x08, 0x00, 0x0E, 0x40, 0x00, 0x10, 
    0x00, 0x08, 0x00, 0x04, 0x00, 0x02, 0x80, 0x00, 0x1C, 0x00, 0x05, 0xE0, 0x03, 0xFC, 0x81, 0xD5, 
    0x20, 0x21, 0x08, 0x08, 0x04, 0x01, 0x00, 0x00, 0x70, 0x00, 0x0C, 0x00, 0x00, 0xC0, 0x01, 0x30, 
    0x00, 0x00, 0x00, 0x07, 0xC0, 0x00, 0x00, 0x08, 0x00, 0x03, 0x60, 0x00, 0x30, 0x00, 0x08, 0x00, 
    0x00, 0x60, 0x00, 0x38, 0x00, 0x00, 0x80, 0x03, 0x60, 0x00, 0x00, 0x00, 0x06, 0x80, 0x03, 0x00, 
    0x00, 0x18, 0x00, 0x0E, 0x80, 0x03, 0x60, 0x00, 0x00, 0x00, 0x0E, 0x80, 0x01, 0x00, 0x1E, 0xC0, 
    0x0F, 0xF0, 0x03, 0xFC, 0x00, 0x3F, 0x80, 0x07, 0x00, 0x00, 0x01, 0x20, 0x00, 0x10, 0x00, 0x02, 
    0x00, 0x01, 0x20, 0x00, 0xF0, 0xF9, 0x7C, 0x3E, 0x00, 0x80, 0x9D, 0xF0, 0x4F, 0x24, 0x12, 0x89, 
    0x44, 0x22, 0x91, 0x7F, 0xC8, 0x0D, 0x00, 0x00, 0x03, 0x20, 0x01, 0x48, 0x00, 0x0C, 0x00, 0x88, 
    0x00, 0x22, 0xE0, 0x0B, 0x20, 0x02, 0x88, 0x00, 0x00, 0x00, 0x00, 0x31, 0x40, 0x0E, 0xF0, 0x02, 
    0x98, 0x00, 0x00, 0x00, 0x00, 0x10, 0x02, 0x94, 0x00, 0x3F, 0x80, 0x06, 0x00, 0x00, 0xE0, 0x3F, 
    0xF8, 0x0F, 0x80, 0x00, 0x20, 0xE0, 0x0F, 0xF8, 0x03, 0x00, 0xC0, 0x01, 0xF8, 0x00, 0x3E, 0x80, 
    0x0F, 0xE0, 0xFF, 0x08, 0x00, 0xFE, 0x0F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x22, 0xC0, 0x0F, 0xF0, 
    0x03, 0x80, 0x00, 0x00, 0x00, 0x00, 0xE0, 0x01, 0xFC, 0x00, 0x21, 0xC0, 0x0F, 0xE0, 0x01, 0x00, 
    0x00, 0x80, 0x33, 0xFE, 0xE0, 0x0F, 0x18, 0x02, 0xFE, 0x30, 0xFE, 0x00, 0x38, 0x00, 0x00, 0xF8, 
    0x00, 0x7F, 0x6C, 0x30, 0x08, 0xC8, 0x06, 0x03, 0x7F, 0x80, 0x0F, 0x00, 0x00, 0x88, 0x00, 0x14, 
    0x00, 0x02, 0x40, 0x01, 0x88, 0x00, 0x00, 0xE0, 0x1F, 0xF8, 0xCF, 0x00, 0x02, 0x80, 0x0C, 0x20, 
    0xF8, 0x0F, 0xFE, 0x01, 0x00, 0xE0, 0x3F, 0xFC, 0x0F, 0x01, 0x40, 0x84, 0xF0, 0x23, 0xB8, 0x0F, 
    0xC0, 0x01, 0x00, 0x00, 0x1C, 0xAC, 0x0F, 0x28, 0x02, 0x8A, 0xB0, 0x3F, 0xC0, 0x0F, 0x00, 0x00, 
    0x7C, 0xB0, 0x3F, 0x20, 0x08, 0x08, 0xC2, 0xFE, 0x00, 0x1F, 0x00, 0x00, 0x20, 0x00, 0x08, 0xC0, 
    0x1A, 0xB0, 0x06, 0x20, 0x00, 0x08, 0x00, 0x00, 0xC0, 0x17, 0xF8, 0x03, 0xA2, 0x80, 0x26, 0xE0, 
    0x0F, 0xF4, 0x01, 0x00, 0x80, 0x1F, 0xEC, 0x0F, 0x00, 0x02, 0x80, 0xB0, 0x3F, 0xE0, 0x0F, 0x00, 
    0x00, 0x00
};
#endif
