/* Copyright (C) 2005, 2006, 2007, 2008 by Thomas Hillebrandt and Heiko Will

This file is part of the Micro-mesh SensorWeb Firmware.

Micro-Mesh is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3, or (at your option)
any later version.

Micro-Mesh is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with Micro-Mesh; see the file COPYING.  If not, write to
the Free Software Foundation, 59 Temple Place - Suite 330,
Boston, MA 02111-1307, USA.  */

/* As a special exception, if you include this header file into source
   files compiled by GCC, this header file does not by itself cause
   the resulting executable to be covered by the GNU General Public
   License.  This exception does not however invalidate any other
   reasons why the executable file might be covered by the GNU General
   Public License.  */

#ifndef FUNK_H_
#define FUNK_H_

#include "type.h"

void set_speed(int speed);
void start_car(void);
void stop_car(void);

#define PACKET_LENGTH		(0x3E)		// Packet length = 62 Bytes.
#define MAX_DATA_LENGTH		(0x3A)		// Maximum data length of layer 0 = 58 Bytes.

#define FIXED_PKTLEN		(0x00)		// Fixed length packets, length configured in PKTLEN register.
#define	VARIABLE_PKTLEN		(0x01)		// Variable length packets, packet length configured by the first
										// byte after synch word.

// Bitmasks for reading out status register values
#define CRC_OK              (0x80)		// Bitmask (=10000000) for reading CRC_OK.
										// If CRC_OK == 1: CRC for received data OK (or CRC disabled).
		 								// If CRC_OK == 0: CRC error in received data.
#define LQI_EST				(0x7F)		// Bitmask (=01111111) for reading LQI_EST.
										// The Link Quality Indicator estimates how easily a received signal can be demodulated.
#define I_RSSI              (0x00)		// Index 0 contains RSSI information (from optionally appended packet status bytes).
#define I_LQI               (0x01)		// Index 1 contains LQI & CRC_OK information (from optionally appended packet status bytes).
#define MARC_STATE			(0x1F)		// Bitmask (=00011111) for reading MARC_STATE in MARCSTATE status register.
#define CS					(0x40)		// Bitmask (=01000000) for reading CS (Carrier Sense) in PKTSTATUS status register.
#define PQT_REACHED			(0x20)		// Bitmask (=00100000) for reading PQT_REACHED (Preamble Quality reached) in PKTSTATUS status register.
#define CCA					(0x10)		// Bitmask (=00010000) for reading CCA (clear channel assessment) in PKTSTATUS status register.
#define SFD					(0x08)		// Bitmask (=00001000) for reading SFD (Sync word found) in PKTSTATUS status register.
#define GDO2				(0x04)		// Bitmask (=00000100) for reading GDO2 (current value on GDO2 pin) in PKTSTATUS status register.
#define GDO1				(0x02)		// Bitmask (=00000010) for reading GDO1 (current value on GDO1 pin) in PKTSTATUS status register.
#define GDO0				(0x01)		// Bitmask (=00000001) for reading GDO0 (current value on GDO0 pin) in PKTSTATUS status register.
#define TXFIFO_UNDERFLOW	(0x80)		// Bitmask (=10000000) for reading TXFIFO_UNDERFLOW in TXBYTES status register.
#define BYTES_IN_TXFIFO		(0x7F)		// Bitmask (=01111111) for reading NUM_TXBYTES in TXBYTES status register.
#define RXFIFO_OVERFLOW		(0x80)		// Bitmask (=10000000) for reading RXFIFO_OVERFLOW in RXBYTES status register.
#define BYTES_IN_RXFIFO     (0x7F)		// Bitmask (=01111111) for reading NUM_RXBYTES in RXBYTES status register.

// Bitmasks for reading out configuration register values
#define PKT_LENGTH_CONFIG	(0x03)		// Bitmask (=00000011) for reading LENGTH_CONFIG in PKTCTRL0 configuration register.

// Configuration Registers (47x)
#define CC1100_IOCFG2       (0x00)      // GDO2 output pin configuration
#define CC1100_IOCFG1       (0x01)      // GDO1 output pin configuration
#define CC1100_IOCFG0       (0x02)      // GDO0 output pin configuration
#define CC1100_FIFOTHR      (0x03)      // RX FIFO and TX FIFO thresholds
#define CC1100_SYNC1        (0x04)      // Sync word, high byte
#define CC1100_SYNC0        (0x05)      // Sync word, low byte
#define CC1100_PKTLEN       (0x06)      // Packet length
#define CC1100_PKTCTRL1     (0x07)      // Packet automation control
#define CC1100_PKTCTRL0     (0x08)      // Packet automation control
#define CC1100_ADDR         (0x09)      // Device address
#define CC1100_CHANNR       (0x0A)      // Channel number
#define CC1100_FSCTRL1      (0x0B)      // Frequency synthesizer control
#define CC1100_FSCTRL0      (0x0C)      // Frequency synthesizer control
#define CC1100_FREQ2        (0x0D)      // Frequency control word, high byte
#define CC1100_FREQ1        (0x0E)      // Frequency control word, middle byte
#define CC1100_FREQ0        (0x0F)      // Frequency control word, low byte
#define CC1100_MDMCFG4      (0x10)      // Modem configuration
#define CC1100_MDMCFG3      (0x11)      // Modem configuration
#define CC1100_MDMCFG2      (0x12)      // Modem configuration
#define CC1100_MDMCFG1      (0x13)      // Modem configuration
#define CC1100_MDMCFG0      (0x14)      // Modem configuration
#define CC1100_DEVIATN      (0x15)      // Modem deviation setting
#define CC1100_MCSM2        (0x16)      // Main Radio Control State Machine configuration
#define CC1100_MCSM1        (0x17)      // Main Radio Control State Machine configuration
#define CC1100_MCSM0        (0x18)      // Main Radio Control State Machine configuration
#define CC1100_FOCCFG       (0x19)      // Frequency Offset Compensation configuration
#define CC1100_BSCFG        (0x1A)      // Bit Synchronization configuration
#define CC1100_AGCCTRL2     (0x1B)      // AGC control
#define CC1100_AGCCTRL1     (0x1C)      // AGC control
#define CC1100_AGCCTRL0     (0x1D)      // AGC control
#define CC1100_WOREVT1      (0x1E)      // High byte Event 0 timeout
#define CC1100_WOREVT0      (0x1F)      // Low byte Event 0 timeout
#define CC1100_WORCTRL      (0x20)      // Wake On Radio control
#define CC1100_FREND1       (0x21)      // Front end RX configuration
#define CC1100_FREND0       (0x22)      // Front end TX configuration
#define CC1100_FSCAL3       (0x23)      // Frequency synthesizer calibration
#define CC1100_FSCAL2       (0x24)      // Frequency synthesizer calibration
#define CC1100_FSCAL1       (0x25)      // Frequency synthesizer calibration
#define CC1100_FSCAL0       (0x26)      // Frequency synthesizer calibration
#define CC1100_RCCTRL1      (0x27)      // RC oscillator configuration
#define CC1100_RCCTRL0      (0x28)      // RC oscillator configuration
#define CC1100_FSTEST       (0x29)      // Frequency synthesizer calibration control
#define CC1100_PTEST        (0x2A)      // Production test
#define CC1100_AGCTEST      (0x2B)      // AGC test
#define CC1100_TEST2        (0x2C)      // Various test settings
#define CC1100_TEST1        (0x2D)      // Various test settings
#define CC1100_TEST0        (0x2E)      // Various test settings

// Strobe commands (14x)
#define CC1100_SRES         (0x30)		// Reset chip.
#define CC1100_SFSTXON      (0x31)      // Enable and calibrate frequency synthesizer (if MCSM0.FS_AUTOCAL=1).
										// If in RX/TX: Go to a wait state where only the synthesizer is
                                        // running (for quick RX / TX turnaround).
#define CC1100_SXOFF        (0x32)      // Turn off crystal oscillator.
#define CC1100_SCAL         (0x33)      // Calibrate frequency synthesizer and turn it off
                                        // (enables quick start).
#define CC1100_SRX          (0x34)      // Enable RX. Perform calibration first if coming from IDLE and
                                        // MCSM0.FS_AUTOCAL=1.
#define CC1100_STX          (0x35)      // In IDLE state: Enable TX. Perform calibration first if
                                        // MCSM0.FS_AUTOCAL=1. If in RX state and CCA is enabled:
                                        // Only go to TX if channel is clear.
#define CC1100_SIDLE        (0x36)      // Exit RX / TX, turn off frequency synthesizer and exit
                                        // Wake-On-Radio mode if applicable.
#define CC1100_SAFC         (0x37)      // Perform AFC adjustment of the frequency synthesizer
#define CC1100_SWOR         (0x38)      // Start automatic RX polling sequence (Wake-on-Radio)
#define CC1100_SPWD         (0x39)      // Enter power down mode when CSn goes high.
#define CC1100_SFRX         (0x3A)      // Flush the RX FIFO buffer (CC1100 should be in IDLE state).
#define CC1100_SFTX         (0x3B)      // Flush the TX FIFO buffer (CC1100 should be in IDLE state).
#define CC1100_SWORRST      (0x3C)      // Reset real time clock.
#define CC1100_SNOP         (0x3D)      // No operation. May be used to pad strobe commands to two
                                        // bytes for simpler software.

// Status registers (12x)
#define CC1100_PARTNUM      (0x30)		// Part number of CC1100.
#define CC1100_VERSION      (0x31)		// Current version number.
#define CC1100_FREQEST      (0x32)		// Frequency Offset Estimate.
#define CC1100_LQI          (0x33)		// Demodulator estimate for Link Quality.
#define CC1100_RSSI         (0x34)		// Received signal strength indication.
#define CC1100_MARCSTATE    (0x35)		// Control state machine state.
#define CC1100_WORTIME1     (0x36)		// High byte of WOR timer.
#define CC1100_WORTIME0     (0x37)		// Low byte of WOR timer.
#define CC1100_PKTSTATUS    (0x38)		// Current GDOx status and packet status.
#define CC1100_VCO_VC_DAC   (0x39)		// Current setting from PLL calibration module.
#define CC1100_TXBYTES      (0x3A)		// Underflow and number of bytes in the TX FIFO.
#define CC1100_RXBYTES      (0x3B)		// Overflow and number of bytes in the RX FIFO.

// Multi byte registers
#define CC1100_PATABLE      (0x3E)		// Register for eight user selected output power settings.
										// 3-bit FREND0.PA_POWER value selects the PATABLE entry to use.
#define CC1100_TXFIFO       (0x3F)		// TX FIFO: Write operations write to the TX FIFO (SB: +0x00; BURST: +0x40)
#define CC1100_RXFIFO       (0x3F)		// RX FIFO: Read operations read from the RX FIFO (SB: +0x80; BURST: +0xC0)

#define FLAGS_IDENTIFICATION	(0x01)			// Bitmask for reading the identification out of the flags field
#define R_FLAGS_PROTOCOL(x)		((x & 0x0E)>>1) // Makro for reading the protocol out of the flags field
#define W_FLAGS_PROTOCOL(x)		((x<<1) & 0x0E) // Makro for writing the protocol in the flags field

// Protocol types of layer 1 (3 bit value)
#define L1_ACK				(0x01)		// Link-Level acknowledgement (LL-ACK)
#define L1_AAODV			(0x02)		// AAODV protocol

// Defines used as state values for state machine
#define RADIO_UNKNOWN			(0)
#define RADIO_AIR_FREE_WAITING	(1)
#define RADIO_WOR				(2)
#define RADIO_IDLE				(3)
#define RADIO_SEND_BURST		(4)
#define RADIO_RX				(5)
#define RADIO_SEND_ACK			(6)

#define ADDR_BROADCAST			(0x00)	// Broadcast address
#define BURST_RETRY_COUNT		(1)		// Number of retries (unicast)

//---------------------------------------------------------------------------------------
// Layer 0 protocol (length & address are given by CC1100):
//
// ---------------------------------------------------
// |        |         |         |       |            |
// | Length | Address | PhySrc  | Flags |    Data    |
// |        |         |         |       |            |
// ---------------------------------------------------
//   1 byte   1 byte    1 byte   1 byte   <= 58 bytes
//
// Flags:
//			Bit | Meaning
//			--------------------
//			7:4	| -
//			3:1 | Protocol
//			  0 | Identification
//
//---------------------------------------------------------------------------------------
typedef struct  __attribute__ ((packed)) p_layer0
{
	uint8_t length;			// Length of the packet (without length byte)
	uint8_t address;			// Destination address
	uint8_t phySrc;			// Source address (Physical Source)
	uint8_t flags;			// Flags
	uint8_t data[58];			// Data (high layer protocol)
} packet_layer0_t;

// Address of this sensornode
extern volatile uint8_t uid;

// Current PATABLE Index
extern uint8_t paTableIndex;

// Radio state of this sensornode
volatile uint8_t radioState;

// Radio Control Flags
struct flags
{
	unsigned RSSI	 : 8;	// The RSSI value of last received packet
	unsigned LL_ACK  : 1;	// Is set if Link-Level ACK is received, otherwise 0 (reset on new burst)
	unsigned CAA     : 1;	// The status of the air (1 = air free, 0 = air not free)
	unsigned CRC     : 1;	// The CRC status of last received packet (1 = OK, 0 = not OK)
	unsigned RX_REQ  : 1;	// RX request (if set, go to RX immediately) (for WOR optimisation)
	unsigned SEQ	 : 1;	// Sequence number (toggles between 0 and 1)
	unsigned MAN_WOR : 1; 	// Manual WOR set (for randomized WOR times => no synch)
	unsigned unused	 : 2;	// Unused
} volatile rflags;

typedef bool (*routing_callback_t)(packet_layer0_t*);

//-------------------------------------------------------------------------------------------------------
//  void initCC1100(routing_callback_t callback)
//
//  DESCRIPTION:
//      Function for initializing the CC1100. Must be called before the radio can be used.
//
//  ARGUMENTS:
//      routing_callback_t callback
//			A callback function of the routing layer which handles incoming packets.
//
//-------------------------------------------------------------------------------------------------------
void initCC1100(routing_callback_t callback,uint8_t id);

//-------------------------------------------------------------------------------------------------------
//  void setWorMode(void)
//
//  DESCRIPTION:
//      Function for setting the chip into WOR (Wake-On-Radio) mode. Has to be called if CC1100
//		is reset. Gets automatically called by initCC1100().
//
//-------------------------------------------------------------------------------------------------------
void setWorMode(void);

//-------------------------------------------------------------------------------------------------------
//  void setUid(uint8_t id)
//
//  DESCRIPTION:
//      Function for setting the address of this sensornode (and address of CC1100).
//		Address range is 1..255, other values are discarded.
//
//  ARGUMENTS:
//      uint8_t id
//			The new address of the sensornode (and address of CC1100 -> CC1100_ADDR register).
//
//-------------------------------------------------------------------------------------------------------
void setUid(uint8_t id);

//-------------------------------------------------------------------------------------------------------
//  void setOutputPower(uint8_t paIdx)
//
//  DESCRIPTION:
//		Sets the output power of the CC1100.
//
//  ARGUMENTS:
//		uint8_t paIdx
//			Index of the output power to use. Range of index: 0 - 12 (-52 dBm to +10 dBm).
//          A lower index means less output power (less dBm) a higher
//			index means more output power (more dBm).
//
//  RETURN VALUE:
//		bool
//			true:	If output power has been set successfully.
//			false:  If output power couldn't be set.
//
//-------------------------------------------------------------------------------------------------------
bool setOutputPower(uint8_t paIdx);

//-------------------------------------------------------------------------------------------------------
//  signed short getLastRSSI(void)
//
//  DESCRIPTION:
//		Gets the RSSI value of the last received packet.
//
//  RETURN VALUE:
//		signed short
//			RSSI value in dBm.
//
//-------------------------------------------------------------------------------------------------------
signed short getLastRSSI(void);

void sendPacket(uint8_t *txBuffer, uint8_t size);

//-------------------------------------------------------------------------------------------------------
//	bool csend(uint8_t addr, uint8_t protocol, uint8_t *data, uint8_t count)
//
//	DESCRIPTION:
//		Sends the data to the given address/sensornode. The maximum data length are 58 bytes.
//		Any data with are higer _count_ will be truncated.
//
//  ARGUMENTS:
//      uint8_t addr
//			Address of the sensornode to which the data should be transmitted.
//		uint8_t protocol
//			The protocol identifier of the higher protocol (encapsulated in payload data).
//		uint8_t *data
//			Pointer to the data to be transmitted.
//		uint8_t length
//			Number of bytes to be written into the packet (the data length).
//			If greater than MAX_DATA_LENGTH bytes, data will be truncated.
//
//  RETURN VALUE:
//		bool
//			true:	If data has been send successfully.
//			false:  If data couldn't be send or no ACK was received.
//
//-------------------------------------------------------------------------------------------------------
bool csend(uint8_t addr, uint8_t protocol, uint8_t *data, uint8_t length);

//-------------------------------------------------------------------------------------------------------
//	void handleRadioEvents(void)
//
//	DESCRIPTION:
//		Must be called on a regular basis to handle the radio events, e.g. out of the main loop
//		or in an ISR. The interval depends on the _WOR_TIMEOUT_ value and should be at minimum half
//		the size.
//
//-------------------------------------------------------------------------------------------------------
void handleRadioEvents(void);

//-------------------------------------------------------------------------------------------------------
//  void spiWriteReg(uint8_t addr, uint8_t value)
//
//  DESCRIPTION:
//      Function for writing to a single CC1100 register.
//
//  ARGUMENTS:
//      uint8_t addr
//          Address of a specific CC1100 register to accessed.
//      uint8_t value
//          Value to be written to the specified CC1100 register.
//-------------------------------------------------------------------------------------------------------
void spiWriteReg(uint8_t addr, uint8_t value);

//-------------------------------------------------------------------------------------------------------
//  void spiStrobe(uint8_t strobe)
//
//  DESCRIPTION:
//      Function for writing a strobe command to the CC1100
//
//  ARGUMENTS:
//      uint8_t strobe
//          Strobe command
//-------------------------------------------------------------------------------------------------------
void spiStrobe(uint8_t strobe);

//-------------------------------------------------------------------------------------------------------
//  void WOR_WAKEUP(void)
//
//  DESCRIPTION:
//      This function must be called for CC1100 WOR-Wakeup. Only after returning from this function valid
//      operation with the CC1100 is possible.
//-------------------------------------------------------------------------------------------------------
void WOR_WAKEUP(void);

#endif /*FUNK_H_*/
