/* Copyright (C) 2005, 2006, 2007, 2008 by Thomas Hillebrandt and Heiko Will

This file is part of the Micro-mesh SensorWeb Firmware.

Micro-Mesh is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3, or (at your option)
any later version.

Micro-Mesh is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with Micro-Mesh; see the file COPYING.  If not, write to
the Free Software Foundation, 59 Temple Place - Suite 330,
Boston, MA 02111-1307, USA.  */

/* As a special exception, if you include this header file into source
   files compiled by GCC, this header file does not by itself cause
   the resulting executable to be covered by the GNU General Public
   License.  This exception does not however invalidate any other
   reasons why the executable file might be covered by the GNU General
   Public License.  */

#include "config.h"

#ifdef INCLUDE_SHT11

#ifndef DRIVER_SHT11_H_
#define DRIVER_SHT11_H_

#include "type.h"
#include "driver_sensor.h"
#include "drivers.h"

typedef union {
	uint16_t i;
	float f;
} sht_value;

typedef struct {
	sht_value humi_val;
	sht_value temp_val;
	uint32_t v_timestamp;
} s_sht11_data;

extern s_sht11_data sht11_data;

//-------------------------------------------------------------------------------------------------------
//  void init_sht11(void)
//
//  DESCRIPTION:
//		Initialize the SHT11 sensor and corresponding data. Must be called before the SHT11 can be used.
//
//-------------------------------------------------------------------------------------------------------
void sht11_init(driver*);

//-------------------------------------------------------------------------------------------------------
//  void sht11_update_data(void)
//
//  DESCRIPTION:
//		Updates the sensor data. To avoid heating up SHT11 the data is only measured if the old data is
//		more than 2 seconds old.
//
//-------------------------------------------------------------------------------------------------------
void sht11_update_data(void);

extern sensor* sht11_humi_new(sensor* this);
extern sensor* sht11_temp_new(sensor* this);

#endif /*DRIVER_SHT11_H_*/
#endif

