/* Copyright (C) 2005, 2006, 2007, 2008 by Thomas Hillebrandt and Heiko Will

This file is part of the Micro-mesh SensorWeb Firmware.

Micro-Mesh is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3, or (at your option)
any later version.

Micro-Mesh is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with Micro-Mesh; see the file COPYING.  If not, write to
the Free Software Foundation, 59 Temple Place - Suite 330,
Boston, MA 02111-1307, USA.  */

#include "config.h"

#ifdef INCLUDE_SDCARD

#include "driver_sd.h"
#include "driver_controller.h"
#include "type.h"
#include "board.h"

static int SPI1Prescaler;

int Spi1SetSpeedKhz(uint16_t speed)
{
	SPI1Prescaler=PCLK/(speed*1000);
	return Switch2Sd();
}

int Switch2Sd(void)
{
	
	SSPCR1 = 0x0;		// Disable SPI
	PINSEL1 |= BIT7+BIT3+BIT5;
	SSPCR0= BIT0+BIT1+BIT2+BIT6+BIT7; 		// 8 Bit Frame 
	SSPCPSR=SPI1Prescaler;
	SSPCR1 = 0x2;		// Enable SPI 1	
	return 0;
}

int LoadSdDriver(void)
{
	int ret = Spi1SetSpeedKhz(200);		// Init Speed ~ 200khz
	if (ret!=0) return ret;
	//Initialisiere MMC/SD-Karte in den SPI-Mode
	uint8_t b;
	for (b = 0;b<10;b++) //Sendet min 74+ Clocks an die MMC/SD-Karte
		SdSend(0xff);
	return 0;
}

uint8_t SdSend(uint8_t data)
{
	uint8_t incomming;
	SSPDR=data;
	/* Wait until the Busy bit is cleared */
	while ((SSPSR & 0x10)) ;     // wait for transfer completed
	incomming = SSPDR;
	return incomming;
}

void SdRecvN(uint8_t * pbBuf, int iLen)
{
	int i;
	for (i = 0; i < iLen; i++) {
		/* as long as TNF bit is set, TxFIFO is not full, I can write */
		SSPDR = 0xFF;
		while ((SSPSR & 0x10)) ;     // wait for transfer completed
		pbBuf[i] = SSPDR;
	}
}

void SdSelect(void)
{
	FIO0CLR = SD_CS_PIN;
}

void SdUnselect(void)
{
	FIO0SET = SD_CS_PIN;
}

#endif


