/* Copyright (C) 2005, 2006, 2007, 2008 by Thomas Hillebrandt and Heiko Will

This file is part of the Micro-mesh SensorWeb Firmware.

Micro-Mesh is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3, or (at your option)
any later version.

Micro-Mesh is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with Micro-Mesh; see the file COPYING.  If not, write to
the Free Software Foundation, 59 Temple Place - Suite 330,
Boston, MA 02111-1307, USA.  */

#include "driver_usertimer.h"
#include "type.h"
#include "driver_controller.h"
#include "driver_system.h"
#include "board.h"
#include "armVIC.h"

void __attribute__ ((interrupt("IRQ"))) RTC_ISR(void);

static callback_t ft_cb;

const int timerspeed = 1;
const int usertimer_histeresis = 1;

void load_usertimer_driver(callback_t of,callback_t ft)
{
	YEAR=2000;
	DOM=1;
	DOY=1;
	MONTH=1;
	SEC=0;
	
	ft_cb=ft;
	CCR=BIT4; 				// Select clock crystal
	CIIR = 0;				// mask all counters interrupts	
  	AMR = 0xff;           	// mask all alarms interrupts
 	ILR = BIT0+BIT1;      	// clear all interrupt flags of RTC
  
  	disableIRQ();							// Disable all interrupts
  	VICIntEnable = BIT13; 					// Enable Interrupthandling for RTC
  	VICVectCntl2 = 13 + BIT5;				// Assign RTC to IRQ Slot 0
  	VICVectAddr2 = (unsigned long)RTC_ISR;	// Assing Isr Address
  
  	INTWAKE |= BIT15; 						// Wakes the uC from powerdown on RTC interrupts
  
  	enableIRQ();	
  	CCR |= BIT0;			// rtc enable
}

void setNextUserTimer(unsigned int total)
{
	if (CTC>16384) total++; 	// if more than half of the actual second is over, inc the timer
	unsigned int year = total / (365*24*3600);
	int lyears = year/4;
	total -= year*(365*24*3600);
	if (total< lyears*24*3600) 
	{
		lyears -= 1;
		year-=1;
		total += (365*24*3600);
	}
	total-= lyears*24*3600;
	unsigned int days = total / (24*3600);
	total -=  days*(24*3600);
	unsigned int hours = total / 3600;
	total -= hours*3600;
	unsigned int minute = total /60;
	total -= minute*60;
	unsigned int seconds = total;
	AMR =  0xff;
	ALSEC=seconds;
	ALMIN=minute;
	ALHOUR=hours;
	ALDOY=1+days;
	ALYEAR=2000+year;
	ILR = BIT0+BIT1;      	// clear all interrupt of RTC
	unsigned int mask= (BIT0+BIT1+BIT2+BIT5+BIT7);
	AMR =  ~mask;
}

void disableUserTimer(void)
{
	AMR = 0xff;           	// initialize interrupt mask register of RTC
	ILR = BIT0+BIT1;      	// clear all interrupt of RTC
}

unsigned int read_usertimer_counter(void)
{
	int lyears= (YEAR - 2000) / 4;
	unsigned int sec = SEC + MINUTE*60 + HOUR*3600 + (DOY-1+lyears)*24*3600 + (YEAR-2000)*365*24*3600;
	return sec;
}

void __attribute__ ((interrupt("IRQ"))) RTC_ISR(void)
{
	if (system_state.POWERDOWN) 
	{
		init_clks();
		system_state.POWERDOWN = false;
	}
	ILR = BIT0+BIT1;      // clear all interrupt of RTC
	ft_cb();
	VICVectAddr=0;  //Dummy write to signal end of interrupt
}
