/* Copyright (C) 2005, 2006, 2007, 2008 by Thomas Hillebrandt and Heiko Will

This file is part of the Micro-mesh SensorWeb Firmware.

Micro-Mesh is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3, or (at your option)
any later version.

Micro-Mesh is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with Micro-Mesh; see the file COPYING.  If not, write to
the Free Software Foundation, 59 Temple Place - Suite 330,
Boston, MA 02111-1307, USA.  */

#include <msp430x16x.h>
#include <signal.h>
#include "driver_flash.h"
#include "type.h"

// Reads the node number from internal flash memory
// first byte has to be 0x77 and second byte is the node_id
// if first byte differs from 0x77 then node_id=0 is assumed.
char readNodeId(void)
{
	unsigned int *adr = (unsigned int*) 0x1000; // of first byte in Info-Mem block B
	unsigned int temp;
	temp =  *adr;
	if ((temp>>8)!=0x77) return 0;
	return (char) (temp - 0x7700);
}

bool writeNodeId(char id)
{
	// erase segment
	unsigned int *adr = (unsigned int*)0x1000;	// of first byte in Info-Mem block B
	dint();						// disable all interrupts
	FCTL2=FWKEY+FSSEL1+13;		// Passwd,MCLK,Divided by 14
	FCTL3=FWKEY;				// Unlock Flash mem
	FCTL1=FWKEY+ERASE;			// Set Erase Mode
	*adr=0x1111;					// Dummy write to start erase;
	FCTL3=FWKEY+LOCK;			// Lock Flash Memory
	eint();						// enable interrupts

	// write flashmem
	unsigned int temp = 0x77;   
	temp= temp<<8;				// move the 77 to upper byte
	temp+=id;					// add the id
	dint();						// disable all interrupts
	FCTL2=FWKEY+FSSEL1+13;		// Passwd,MCLK,Divided by 14
	FCTL3=FWKEY;				// Unlock Flash mem
	FCTL1=FWKEY+WRT;			// Set Write Mode
	*adr=temp;					// Write data to flash
	FCTL1=FWKEY;				// Unset Write Mode
	FCTL3=FWKEY+LOCK;			// Lock Flash Memory
	eint();						// enable interrupts
	return true;
}
