/* Copyright (C) 2005, 2006, 2007, 2008 by Thomas Hillebrandt and Heiko Will

This file is part of the Micro-mesh SensorWeb Firmware.

Micro-Mesh is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3, or (at your option)
any later version.

Micro-Mesh is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with Micro-Mesh; see the file COPYING.  If not, write to
the Free Software Foundation, 59 Temple Place - Suite 330,
Boston, MA 02111-1307, USA.  */

#include "config.h"
#include <msp430x16x.h>

#ifdef INCLUDE_SDCARD

#include "driver_sd.h"
#include "type.h"
#include "std_defines.h"
#include "driver_system.h"

static int SPI1Prescaler;

#define PCLK 7372800
#define NOBYTE				(0x00)		// No command, for reading.

int Spi1SetSpeedKhz(uint16_t speed)
{
	SPI1Prescaler=PCLK/(((uint32)speed*1000));
	return Switch2Sd();
}

int Switch2Sd(void)
{
	if (P2IN & 0x80) return -1;
	hardware_config.DEBUG_UART_ACTIVE=0;
	hardware_config.SDCARD_ACTIVE=1;
	
	// Uart ausschalten
	P3SEL &= ~0xC0;
	P5SEL |= 0x0E;				// Set pin as SPI
	// Keep peripheral in reset state
	UCTL1  = SWRST;

	IE2 &= ~(URXIE1 + UTXIE1);	// Disable USART0 receive&transmit interrupt
	ME2 &= ~(UTXE1 + URXE1);
	// Enable SPI mode
	ME2 |= USPIE1;

	// 8-bit SPI Master 3-pin mode, with SMCLK as clock source
	U1CTL |= CHAR + SYNC + MM;
	// CKPL works also, but not CKPH+CKPL or none of them!!
	U1TCTL = TXEPT + SSEL1 + SSEL0 + STC + CKPH;
	
	U1RCTL = 0x00; // Reset Receive Control Register
	// Ignore clockrate argument for now, just use clock source/2
	// SMCLK = 7,3728 MHz
	UBR01 = SPI1Prescaler;  // Ensure baud rate >= 2
	UBR11 = 0x00;
	U1MCTL = 0x00; // No modulation

	// Release for operation
	UCTL1  &= ~SWRST;
	return 0;
}

int LoadSdDriver(void)
{
	int tmp;
	tmp=Spi1SetSpeedKhz(200);		// Init Speed ~ 200khz
	if (tmp!=0) return -1;
	//Initialisiere MMC/SD-Karte in den SPI-Mode
	uint8_t b;
	for (b = 0;b<10;b++) //Sendet min 74+ Clocks an die MMC/SD-Karte
		SdSend(0xff);
	return 0;
}

uint8_t SdSend(uint8_t data)
{
	// Ensure TX Buf is empty
	long c = 0;
	IFG2 &= ~URXIFG1;
	IFG2 &= ~UTXIFG1;
	TXBUF1 = data;
	while(!(IFG2 & UTXIFG1))
	{
		if (c++ == 1000000) 
			alarm();
	}
	
	// Wait for Byte received
	c = 0;
	while(!(IFG2 & URXIFG1))
	{
		if (c++ == 1000000) 
			alarm();	
	}
	return RXBUF1;
}

void SdRecvN(uint8_t * pbBuf, int iLen)
{
	uint8_t i;
	for (i = 0; i < iLen; i++)
	{
		long c = 0;
		IFG2 &= ~URXIFG1;
		IFG2 &= ~UTXIFG1;
		TXBUF1 = NOBYTE;
		while(!(IFG2 & UTXIFG1))
		{
			if (c++ == 1000000) 
				alarm();
		}
		// Wait for Byte received
		c = 0;
		while(!(IFG2 & URXIFG1))
		{
			if (c++ == 1000000) 
				alarm();
		}
		pbBuf[i] = RXBUF1;
	}
}

void SdSelect(void)
{
	if (!hardware_config.SDCARD_ACTIVE)
	{
		Switch2Sd();		
	}
	CLEAR(P5OUT,0x01);
}

void SdUnselect(void)
{
	SET(P5OUT,0x01);
}

#endif


