/* Copyright (C) 2005, 2006, 2007, 2008 by Thomas Hillebrandt and Heiko Will

This file is part of the Micro-mesh SensorWeb Firmware.

Micro-Mesh is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3, or (at your option)
any later version.

Micro-Mesh is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with Micro-Mesh; see the file COPYING.  If not, write to
the Free Software Foundation, 59 Temple Place - Suite 330,
Boston, MA 02111-1307, USA.  */

#include <msp430x16x.h>
#include <stdlib.h>
#include <signal.h>
#include <stdio.h>
#include "driver_timer.h"
#include "type.h"
#include "std_defines.h"
#include "driver_system.h"
#include "spi0.h"
#include "smallib.h"

static callback_t timer_p;

/* Global Vars */
volatile uint32_t ticks;
uint32_t mTicks;

void driver_timer_load(callback_t timer_proc)
{
	timer_p = timer_proc;
  	ticks = 0;								 // Set tick counter value to 0
	TBCTL |= TBCLR;					  		 // Clear the TBR (TBR = 0)
	TBCTL &= ~TBIFG;						 // Clear the IFG
	TBCTL = CNTL_0 + TBSSEL_1 + MC_2 + ID_2; // Counter length = 16 bit, Taktquelle = ACLK, Upmode, Teiler = 4 => 8192 Hz
	TBCCR2 = TIMERB_CCR0;					 // Bei jeder TIMERB_CCR0*4. Flanke des Uhrenquarzes den Interrupt auslösen
	TBCCTL2 &= ~CCIFG;						 // Clears compare IFG
	TBCCTL2 |= CCIE;						 // CCR0 interrupt enabled
	TBCTL |= TBIE;
}

unsigned int get_timer_count(void)
{
	// Save TBR register value
	unsigned int tbrDump = 0, tbrdump2 = 1;
	while(tbrDump != tbrdump2)
	{
		tbrDump = TBR;
		tbrdump2 = TBR;
	}
	return tbrDump;
}

void _wait(unsigned int num)
{
	uint16_t co = TBR + num;
	while (TBR > co);
	while (TBR < co);
}


volatile int sheduler_back;
volatile int sheduler_main_sr;
volatile int sheduler_main;
volatile int userapp_sp;

void activate_sheduler(void)
{
	register unsigned int tbrDump = get_timer_count();
	TBCCR0 = tbrDump+1000;
	TBCCTL0 &= ~(CCIFG);
	TBCCTL0 |= CCIE;
}

void disable_sheduler(void)
{
	TBCCTL0 &= ~(CCIE);
	TBCCTL0 &= ~(CCIFG);
}

interrupt(TIMERB0_VECTOR) ticks_isr(void)
{
	TBCCTL2 &= ~(CCIFG);
	asm(
									  // r2 und Sprungadresse der Userapp liegen noch auf dem Stack
		"mov #2, sheduler_back  \n\t" // Unterbrechen kennzeichnen!
		"push r4 \n\t" 				  // Alle Register der Userapp sichern
		"push r5 \n\t"					
		"push r6 \n\t"
		"push r7 \n\t"
		"push r8 \n\t"
		"push r9 \n\t"
		"push r10 \n\t"
		"push r11 \n\t"
		"push r12 \n\t"
		"push r13 \n\t"
		"push r14 \n\t"
		"push r15 \n\t"
		"mov r1, userapp_sp \n\t" //Stackpointer sichern
		"push sheduler_main \n\t"	  // Aktuelle Adresse der Main auf den Stack
		"push sheduler_main_sr \n\t"  // r2 der Main auf den Stack
		); // Interrupt wird mit Reti abgeschlossen und r2 und rücksprung vom Stack geladen.
}

void switch_userapp(void)
{
	asm(
		"pop r3 \n\t" // rücksprungadresse von switch_userapp vernichten	
		"mov userapp_sp, r1 \n\t" //Stackpointer wiederherstellen 
		"mov r2,sheduler_main_sr \n\t" // Statusregister der Main sichern
		"pop r15 \n\t" // Register der Userapp wiederherstellen
		"pop r14 \n\t"
		"pop r13 \n\t"
		"pop r12 \n\t"	
		"pop r11 \n\t"		
		"pop r10 \n\t"			
		"pop r9 \n\t"
		"pop r8 \n\t"
		"pop r7 \n\t"
		"pop r6 \n\t"
		"pop r5 \n\t"
		"pop r4 \n\t"
		"reti \n\t" // Rücksprung und r2 liegen noch vom unterbrechen auf dem Stack
					// Daher ist es am schnellsten mit reti zurückzuspringen
		);
}

void start_user_thread(callback_t thread)
{	
	asm volatile(
		"pop sheduler_main \n\t" // Rücksprungadresse sichern
		"mov r2, sheduler_main_sr \n\t" // Statusregister der Main sichern
		"push r15 \n\t"			 // Thread Startadresse sichern
		"call #activate_sheduler \n\t"
		"pop r15 \n\t"			 // Thread Startadresse zurückholen	
		"call r15 \n\t"			 // In den Thread springen
								 // Thread hat geendet
		"call #disable_sheduler \n\t"	// Sheduler Timer anhalten
		"cmp #0,sheduler_back \n\t"	// Wurde der Thread unterbrochen
		"jz end \n\t"				// Wenn nein, war dies ein normaler funktionsaufruf
		"mov #0,sheduler_back \n\t" // Wenn ja, Den Zustand vom vorm *letzten* Einsprung wiederherstellen
		"mov sheduler_main_sr, r2 \n\t"
		"end: \n\t"
		"mov sheduler_main, r0 \n\t" // Zurückspringen
		);
}

void continue_thread(void)
{
	sheduler_back=2;
}

void sleep(unsigned int secs)
{
	asm(
			"push r2 \n\t"
			"push r15 \n\t"			 // Thread Startadresse sichern
			"call #disable_sheduler \n\t"
			"mov #1,sheduler_back \n\t"
			"pop r15 \n\t"			 // Thread Startadresse zurückholen	
										  // r2 und Sprungadresse der Userapp liegen noch auf dem Stack
			"push r4 \n\t" 				  // Alle Register der Userapp sichern
			"push r5 \n\t"					
			"push r6 \n\t"
			"push r7 \n\t"
			"push r8 \n\t"
			"push r9 \n\t"
			"push r10 \n\t"
			"push r11 \n\t"
			"push r12 \n\t"
			"push r13 \n\t"
			"push r14 \n\t"
			"push r15 \n\t"
			"mov r1, userapp_sp \n\t" //Stackpointer sichern
			"push sheduler_main \n\t"	  // Aktuelle Adresse der Main auf den Stack
	); // Interrupt wird mit Reti abgeschlossen und r2 und rücksprung vom Stack geladen.
	//registerUserTimer(continue_thread, secs);
}

interrupt(TIMERB1_VECTOR) timer_isr(void)
{
	int tif=TBIV;
	if (tif == TBIV_CCR1)
	{
		if (system_state.POWERDOWN) SPI_INIT;	 // Initialize SPI after wakeup
			timer_p();
			TBCCTL1 &= ~(CCIFG);
			if (system_state.POWERDOWN) END_LPM3;	 // Wake up from LPM3
	}
	else if (tif == TBIV_CCR2)
	{
		ticks += TIMERB_CCR0;					 // Increased every ~8 sec
		TBCCTL2 &= ~CCIFG;						 // Clears compare IFG
	}
}

uint32_t* TICKS(void)
{
	unsigned int tbrDump = get_timer_count();
	mTicks = (uint32_t)(ticks + (uint32_t) tbrDump);
	return &mTicks;
}

void set_next_timer_value(unsigned int ticks)
{
	TBCCR1 = ticks;
	TBCCTL1 &= ~(CCIFG);
	TBCCTL1 |= CCIE;
}

void disable_timer(void)
{
	TBCCTL1 &= ~(CCIE);
	TBCCTL1 &= ~(CCIFG);
}
