/* Copyright (C) 2005, 2006, 2007, 2008 by Thomas Hillebrandt and Heiko Will

This file is part of the Micro-mesh SensorWeb Firmware.

Micro-Mesh is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3, or (at your option)
any later version.

Micro-Mesh is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with Micro-Mesh; see the file COPYING.  If not, write to
the Free Software Foundation, 59 Temple Place - Suite 330,
Boston, MA 02111-1307, USA.  */

#include <msp430x16x.h>
#include <signal.h>
#include <string.h>
#include <stdint.h>
#include "driver_uart1.h"
#include "driver_system.h"
#include "std_defines.h"
#include "type.h"
#include "spi0.h"
#include "drivers.h"


/* External Firmware invokes*/
extern void dm_activate(driver* d);

/* Private functions */
static void uart_init(driver* this);
static inline void clock_init();

/* Private fields*/
static driver_serial *active;

/* Public definitions */

driver_serial* uart1_new(void* char_in_ref,driver_cb_cin_t char_in,driver_serial* this)
{
	this->driver.base.init= uart_init;
	this->driver.activate= uart_init;
	this->char_in = char_in;
	this->put_char = uart1_put_char;
	this->char_in_ref = char_in_ref;
	this->driver.base.active = 0;
	this->driver.base.awake = 1;
	return this;
} 

/* Private definitions */
void uart1_put_char(driver* this,int character)
{	
	if (!this->active) {
		//dm_activate((driver*)this);
		uart_init(this);
		}
	// Write to transmit buffer
	U1TXBUF = (char)character;
	// Wait for empty transmit buffer
	while((U1TCTL & TXEPT) == 0x00);
}

interrupt (UART1RX_VECTOR) UART1RX_ISR(void) {
	// If start edge detected, toggle & return
	if (!(IFG2 & URXIFG1)) {
		U1TCTL &= ~URXSE;
		mEventFlags.Bits.UART_EDGE_DETECT = 1;
		clock_init();
		// Wake up from LPM3
		if (system_state.POWERDOWN) {
			END_LPM3;
		}
		return;
	}
	// Initialize SPI after wakeup
	if (mEventFlags.Bits.UART_EDGE_DETECT) SPI_INIT;
		mEventFlags.Bits.UART_EDGE_DETECT = 0;
	if (active!=NULL){
		active->char_in(active->char_in_ref,U1RXBUF);
	}
	if (system_state.POWERDOWN) {
			END_LPM3;
		}
}


inline void clock_init()
{
	U1CTL |= CHAR; 		// Format 8N1
	U1TCTL = SSEL1 + URXSE;	// Taktquelle SMCLK, enable UART receive start-edge feature
	U1BR0 = 0x40;  		// Teiler Low-Teil  des Taktes 64, da 7372800/64 ca. 115200
	U1BR1 = 0x00;		// Teiler	High-Teil
}

void uart_init(driver *this)
{
	// For the moment, this UART implementation only
    // supports communication settings 115200 8N1
    // i.e. ignore baudrate and options arguments.

	// Initialize UART
	P3SEL |= 0xC0;		// USART RX und TX dem Modul zuweisen
	U1CTL = SWRST; 		// Reset
	clock_init();
	U1MCTL = 0x00; 		// Modulationskontrolle
	ME2 |= URXE1 + UTXE1;
	U1CTL &= ~SWRST;	// Reset
	IFG1 &= ~UTXIFG0;  // initales interrupt-flag loeschen
	IE2 |= URXIE1;
	this->active=1;
	active=(driver_serial*)this;
}

void deactivate(driver_serial* this)
{
	this->driver.base.active=0;
	IFG1 &= ~UTXIFG0;  // interrupt-flag loeschen
	IE2 &= ~URXIE1;	
}





