/* Copyright (C) 2005, 2006, 2007, 2008 by Thomas Hillebrandt and Heiko Will

This file is part of the Micro-mesh SensorWeb Firmware.

Micro-Mesh is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3, or (at your option)
any later version.

Micro-Mesh is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with Micro-Mesh; see the file COPYING.  If not, write to
the Free Software Foundation, 59 Temple Place - Suite 330,
Boston, MA 02111-1307, USA.  */

#include "spi0.h"
#include <msp430x16x.h>
#include "type.h"

void spi0_init(uint8_t clockrate)
{
	// Switch off async UART
	while(!(UTCTL0 & TXEPT));	// Wait for empty UxTXBUF register
	IE1 &= ~(URXIE0 + UTXIE0);	// Disable USART0 receive&transmit interrupt
	ME1 &= ~(UTXE0 + URXE0);
	P3SEL |= 0x0E;				// Set pin as SPI

	// Keep peripheral in reset state
	UCTL0  = SWRST;

	// 8-bit SPI Master 3-pin mode, with SMCLK as clock source
	// CKPL works also, but not CKPH+CKPL or none of them!!
	UCTL0 |= CHAR + SYNC + MM;
	UTCTL0 = CKPH + SSEL1 + SSEL0 + STC;
	
	// Ignore clockrate argument for now, just use clock source/2
	// SMCLK = 7,3728 MHz
	UBR00 = 0x02;  // Ensure baud rate >= 2
	UBR10 = 0x00;
	UMCTL0 = 0x00; // No modulation
	URCTL0 = 0x00; // Reset Receive Control Register
   
	// Enable SPI mode
	ME1 |= USPIE0;

	// Release for operation
	UCTL0  &= ~SWRST;
}

