/* Copyright (C) 2005, 2006, 2007, 2008 by Thomas Hillebrandt and Heiko Will

This file is part of the Micro-mesh SensorWeb Firmware.

Micro-Mesh is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3, or (at your option)
any later version.

Micro-Mesh is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with Micro-Mesh; see the file COPYING.  If not, write to
the Free Software Foundation, 59 Temple Place - Suite 330,
Boston, MA 02111-1307, USA.  */

/**********************************************************
                  Header files
 **********************************************************/
#include "type.h"
#include "driver_system.h"
#include <msp430x16x.h>


/**********************************************************
                      Initialize
**********************************************************/
void Set_DCO (void)   ;
void init_clks(void)
{
    uint16_t i;

	// Stop watchdog
	WDTCTL = WDTPW + WDTHOLD;

	//Init crystal for mclk
	//XT2 = HF XTAL
	BCSCTL1 = RSEL2;

	// Wait for xtal to stabilize
	do {
		IFG1 &= ~OFIFG;				// Clear oscillator fault flag
		for (i = 0xFF; i > 0; i--); // Time for flag to set
	}
	while ((IFG1 & OFIFG) != 0);	// Oscillator fault flag still set?
	BCSCTL2 = SELM_2 + SELS;		// MCLK und SMCLK = XT2 (safe)
}

void Set_DCO (void)                         // Set DCO to selected frequency
//------------------------------------------------------------------------------
{
#define DELTA 223   // (125 war voreingestell)target DCO = DELTA*(32768)

  unsigned int Compare, Oldcapture = 0;
  BCSCTL2 |= DCOR;
  CCTL2 = CM_1 + CCIS_1 + CAP;              // CAP, ACLK
  TACTL = TASSEL_2 + MC_2 + TACLR;          // SMCLK, cont-mode, clear
  int i=0;
  while (1)
  {
    while (!(CCIFG & CCTL2));               // Wait until capture occured
    i++;
    CCTL2 &= ~CCIFG;                        // Capture occured, clear flag
    Compare = CCR2;                         // Get current captured SMCLK
    Compare = Compare - Oldcapture;         // SMCLK difference
    Oldcapture = CCR2;                      // Save current captured SMCLK

    if (DELTA == Compare) break;            // If equal, leave "while(1)"
    else if (DELTA < Compare)               // DCO is too fast, slow it down
    {
      DCOCTL--;
      if (DCOCTL == 0xFF)
      {
        if (!(BCSCTL1 == (XT2OFF)))
        BCSCTL1--;                          // Did DCO roll under?, Sel lower RSEL
      }
    }
    else
    {
      DCOCTL++;
      if (DCOCTL == 0x00)
        {
          if (!(BCSCTL1 == (XT2OFF + 0x07)))
          BCSCTL1++;                        // Did DCO roll over? Sel higher RSEL
        }
    }
    if (i==100) break;
  }
  CCTL2 = 0;                                // Stop CCR2
  TACTL = 0;                                // Stop Timer_A
}


void init_ports(void)
{
	// Port 1: Free port, for energy saving all outputs are set to zero.

    P1SEL = 0x00;	// Port1 Zweitfunktion
    P1OUT = 0x00;	// Port1 Ausgangsregister: 00000000 = 0x00
    P1DIR = 0xFC;	// Port1 Direction: 11111100 = 0xFC
    				//   0 - P1.0 [EINGANG] - Zeitgeber 1 (Reed-Kontakt)
    				//   0 - P1.1 [EINGANG] - Zeitgeber 2 (Reed-Kontakt)
    				//   1 - P1.2 [AUSGANG] - ungenutzt
    				//   1 - P1.3 [AUSGANG] - ungenutzt
    				//   1 - P1.4 [AUSGANG] - ungenutzt
    				//   1 - P1.5 [AUSGANG] - ungenutzt
    				//   1 - P1.6 [AUSGANG] - ungenutzt
    				//   1 - P1.7 [AUSGANG] - ungenutzt

	P2SEL = 0x20;	// Port2 Zweitfunktion
	P2OUT = 0x00;	// Port2 Ausgangsregister: 00000000 = 0x00
	P2DIR = 0x1C;	// Port2 Direction: 00011100 = 0x1C
					//   0 - P2.0 [EINGANG] - CC1100_GDO2
					//   0 - P2.1 [EINGANG] - CC1100_GDO0
					//   1 - P2.2 [AUSGANG] - ungenutzt
					//   1 - P2.3 [AUSGANG] - ungenutzt
					//   1 - P2.4 [AUSGANG] - ungenutzt
					//   0 - P2.5 [EINGANG] - ROSC not used
					//   0 - P2.6 [EINGANG] - SD-KARTE Protect
					//   0 - P2.7 [EINGANG] - SD-KARTE Detect

	P3SEL = 0xC0;	// Port3 Zweitfunktion
	P3OUT = 0x09;	// Port3 Ausgangsregister: 00001001 = 0x09
	P3DIR = 0x2B;	// Port3 Direction: 00101011 = 0x2B
					//   1 - P3.0 [AUSGANG] - CC1100_CSN
					//   1 - P3.1 [AUSGANG] - CC1100_SI
					//   0 - P3.2 [EINGANG] - CC1100_SO
					//   1 - P3.3 [AUSGANG] - CC1100_SCLK
					//   0 - P3.4 [EINGANG] - SHT 11 DATA (AUSGANG/EINGANG)
					//   1 - P3.5 [AUSGANG] - SHT 11 CLK
					//   0 - P3.6 [2-Funktion] - RS232_RxD
					//   0 - P3.7 [2-Funktion] - RS232_TxD

	// Port 4: Free port, for energy saving all outputs are set to zero.

	P4SEL = 0x00;	// Port4 Zweitfunktion
	P4OUT = 0x00;	// Port4 Ausgangsregister: 00000000 = 0x00
	P4DIR = 0x7F;	// Port4 Direction: 01111111 = 0x7F
					//   1 - P4.0 [AUSGANG] - ungenutzt
					//   1 - P4.1 [AUSGANG] - ungenutzt
					//   1 - P4.2 [AUSGANG] - ungenutzt
					//   1 - P4.3 [AUSGANG] - ungenutzt
					//   1 - P4.4 [AUSGANG] - ungenutzt
					//   1 - P4.5 [AUSGANG] - ungenutzt
					//   1 - P4.6 [AUSGANG] - ungenutzt
					//   0 - P4.7 [EINGANG] - ungenutzt

	P5SEL = 0x00;	// Port5 Zweitfunktion: 00000000 = 0x00
	P5OUT = 0xC0;	// Port5 Ausgangsregister: 11000000 = 0xC0
	P5DIR = 0xFF;	// Port5 Direction: 11111011 = 0xFB
					//   1 - P5.0 [AUSGANG] - SD-KARTE /CS
					//   1 - P5.1 [AUSGANG] - SD-KARTE DI
					//   0 - P5.2 [EINGANG] - SD-KARTE DO
					//   1 - P5.3 [AUSGANG] - SD-KARTE DCLK
					//   1 - P5.4 [AUSGANG] - MMA GS1
					//   1 - P5.5 [AUSGANG] - MMA GS2
					//   1 - P5.6 [AUSGANG] - MMA /SLEEP
					//   1 - P5.7 [AUSGANG] - LED_ROT 0-an, 1-aus

	P6SEL = 0x07;	// Port6 Zweitfunktion = 0x07
	P6OUT = 0x00;	// Port6 Ausgangsregister: 00000000 = 0x00
	P6DIR = 0xF8;	// Port6 Direction: 11111000 = 0xF8
					//   0 - P6.0 [AD-EINGANG] - MMA X-Achse
					//   0 - P6.1 [AD-EINGANG] - MMA Y-Achse
					//   0 - P6.2 [AD-EINGANG] - MMA Z-Achse
					//   1 - P6.3 [AUSGANG] - ungenutzt
					//   1 - P6.4 [AUSGANG] - ungenutzt
					//   1 - P6.5 [AUSGANG] - ungenutzt
					//   1 - P6.6 [AUSGANG] - ungenutzt
					//   1 - P6.7 [AUSGANG] - ungenutzt
}

