#include <stdio.h>
#include <stdint.h>
#include "smallib.h"
#include "helpers.h"
#include "usertimer.h"
#include "hardware.h"
#include "rulesystem.h"
#include "net.h"

#define MAX_RULES 10
static rule_t rules[MAX_RULES];


/* #####################################################################################################
 * # time # if a # if b # thenop # elseop # thenact # elseact # ifop # period # id
 * # 4    #  6   #  6   #   6    #   6    #   6     #    6    #   1  #  1     #  2
 * 
 * 
 * 
 */

///
/// Empty getter
///
int init_rulesystem(void){
	int i;
	rule_t tmp;
	tmp.id = 0;
	for (i=0; i < MAX_RULES; i++)
	{
		rules[i] = tmp;
	}
	return 0;
}


float get_sensor_value(uint16_t id){
	return std_devices->sensors[id]->get_value(std_devices->sensors[id]);
}

long get_time(){
	return 0x12345678;
}

///
///	Eval Functions
///
typed_value_t* eval_sensor(typed_value_t* val,typed_value_t *ret){
	ret->valtype = t_float;
	ret->value_t.fval=get_sensor_value(val->value_t.uval);
	return ret;
}

typed_value_t* eval_value(typed_value_t* val,typed_value_t *ret){
	ret->valtype = val->valtype;
	ret->value_t.lval = val->value_t.lval;
	return ret;
}

const evalfunc_t eval_functions[2] = {eval_sensor,eval_value};

///
/// Binary Operators
///

int cmp(uint8_t type, typed_value_t* a, typed_value_t* b){
static const void* funcs [6][4] = {{&&eq,&&eq,&&eq,&&eq},{&&sm_i,&&sm_f,&&sm_u,&&sm_l},{&&gr_i,&&gr_f,&&gr_u,&&gr_l},{&&se_i,&&se_f,&&se_u,&&se_l},{&&ge_i,&&ge_f,&&ge_u,&&ge_l},{&&ne,&&ne,&&ne,&&ne}};
	goto *funcs[type][a->valtype];
eq: 
 	return (a->value_t.lval == b->value_t.lval);
sm_i:
	return (a->value_t.ival < b->value_t.ival);
sm_l:
	return (a->value_t.lval < b->value_t.lval);
sm_u:
	return (a->value_t.uval < b->value_t.uval);
sm_f:
	return (a->value_t.fval < b->value_t.fval);
gr_i:
	return (a->value_t.ival > b->value_t.ival);
gr_l:
	return (a->value_t.lval > b->value_t.lval);
gr_u:
	return (a->value_t.uval > b->value_t.uval);
gr_f:
	return (a->value_t.fval > b->value_t.fval);
ge_i:
	return (a->value_t.ival >= b->value_t.ival);
ge_l:
	return (a->value_t.lval >= b->value_t.lval);
ge_u:
	return (a->value_t.uval >= b->value_t.uval);
ge_f:
	return (a->value_t.fval >= b->value_t.fval);
se_i:
	return (a->value_t.ival <= b->value_t.ival);
se_l:
	return (a->value_t.lval <= b->value_t.lval);
se_u:
	return (a->value_t.uval <= b->value_t.uval);
se_f:
	return (a->value_t.fval <= b->value_t.fval);
ne:
	return (a->value_t.lval != b->value_t.lval);
}

///
/// action functions
///
int action_logg(int rule,expression *operation,expression *operand){
	char buf[10];
	typed_value_t x;
	eval_sensor(&operand->value,&x);
	float2string(buf, x.value_t.fval, 2, 3, 1);
	sl_printf("Logged Sensor %u: %s because of rule %u \n",operand->value.value_t.uval,buf,rule);
	return 0;
}

int action_send(int rule,expression *operation,expression *operand){
	char buf[10];
	typed_value_t x;
	eval_sensor(&operand->value,&x);
	
	/* Log to console */
	float2string(buf, x.value_t.fval, 2, 3, 1);
	sl_printf("Send to node %u: Sensor %u: %s because of rule %u \n",operation->value.value_t.uval,operand->value.value_t.uval,buf,rule);
	return 0;
	
	/* Build paket */
	uint8_t buffer[52];
	int pos=0;

	buffer[pos] = x.valtype;
	pos += sizeof(uint8_t);
	if (x.valtype == t_float){
		sl_memcpy(buffer+pos,&x.value_t.fval,sizeof(float));
		pos+=sizeof(float);
	}
	if (x.valtype == t_uint){
		sl_memcpy(buffer+pos,&x.value_t.uval,sizeof(uint16_t));
		pos+=sizeof(uint16_t);
	}
	sl_memcpy(buffer+pos,&operand->value.value_t.uval,sizeof(uint16_t));
	pos+=sizeof(uint16_t);
	buffer[pos]=0;
	net_send(131, operation->value.value_t.uval, buffer);
}

int action_actor(int rule,expression *operation,expression *operand){
	char buf[10];
	float2string(buf, operand->value.value_t.fval, 2, 3, 1);
	sl_printf("Set Actor %u to %s because of rule %u \n",operation->value.value_t.uval,buf,rule);
	return 0;
}

const thenop_t thens[3] = {action_send,action_logg,action_actor};

void apply_rule(rule_t *rule){
		typed_value_t ifa,ifb;
		if (cmp((uint8_t)rule->ifoperation,eval_functions[(int)rule->if_a.func](&rule->if_a.value,&ifa),eval_functions[(int)rule->if_b.func](&rule->if_b.value,&ifb)))
		{
			thens[(int)rule->thenoperation.func](rule->id,&rule->thenoperation,&rule->thenoperand);		
		}
		else
		{
			thens[(int)rule->elseoperation.func](rule->id,&rule->elseoperation,&rule->elseoperand);	
		}
}

#if DEBUGRULESYSTEM
void printrule(rule_t *rule){
	char *actions[] = {"Sensor","Wert"};
	char *binops[] = {"==","<",">","<=",">=","!="};
	char *thens[] = {"sende","logge","schalte"};
	float a=0 , b=0;
	if (rule->if_a.value.valtype==t_float) a = rule->if_a.value.value_t.fval;
	if (rule->if_a.value.valtype==t_uint) a = rule->if_a.value.value_t.uval;
	if (rule->if_a.value.valtype==t_long) a = rule->if_a.value.value_t.lval;
	if (rule->if_b.value.valtype==t_float) b = rule->if_b.value.value_t.fval;
	if (rule->if_b.value.valtype==t_uint) b = rule->if_b.value.value_t.uval;
	if (rule->if_b.value.valtype==t_long) b = rule->if_b.value.value_t.lval;
	
	char abuf[10];
	char bbuf[10];
	float2string(abuf, a, 2, 3, 1);
	float2string(bbuf, b, 2, 3, 1);
	sl_printf("Wenn %s[%s] %s %s[%s] dann %s[%u] %s[%u] ansonsten %s[%u] %s[%u]\n",actions[rule->if_a.func],abuf,binops[rule->ifoperation],actions[rule->if_b.func],bbuf,
																thens[rule->thenoperation.func],rule->thenoperation.value.value_t.uval,actions[rule->thenoperand.func],rule->thenoperand.value.value_t.uval,
																thens[rule->elseoperation.func],rule->elseoperation.value.value_t.uval,actions[rule->elseoperand.func],rule->elseoperand.value.value_t.uval);

	int i;
	for (i = 0; i < sizeof(rule_t); i++) {
		sl_printf ("%u ",(uint8_t) *(((char*)rule)+i));
		if ((i + 1) % 16 == 0) {
			sl_printf ("\n");
		}
	}
}
#endif

void fire_rule(void* rule){
	rule_t* r = (rule_t*) rule;
	apply_rule(r);
	if (r->check_period){
		//r->check_period = registerUserTimer(fire_rule,(uint16_t)r->timestamp,rule) + 1;
	}
}

int del_rule(uint8_t id){
	if (rules[id].check_period){
		//deleteUserTimer(rules[id].check_period-1);
	}
	rules[id].id = 0;
	return id;
}

int add_rule(rule_t *rule)
{
	int i;
	for (i=0; i < MAX_RULES; i++)
	{
		if (rules[i].id == 0) break;
	}
	if (i == MAX_RULES) return -1;
	sl_memcpy(&rules[i], rule, sizeof(rule_t));
	rules[i].id = i;
	//rules[i].check_period = registerUserTimer(fire_rule,(uint16_t)rule->timestamp,&rules[i]) + 1;
	return i;
}
