/* Copyright (C) 2005, 2006, 2007, 2008 by Thomas Hillebrandt and Heiko Will

This file is part of the Micro-mesh SensorWeb Firmware.

Micro-Mesh is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3, or (at your option)
any later version.

Micro-Mesh is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with Micro-Mesh; see the file COPYING.  If not, write to
the Free Software Foundation, 59 Temple Place - Suite 330,
Boston, MA 02111-1307, USA.  */

#include <stdarg.h>
#include <string.h>
#include "smallib.h"
#include "hardware.h"

int sl_getchar()
{
	return std_devices->stdio_device->get_char(std_devices->stdio_device);
}

int sl_putchar(int c)
{
	return std_devices->stdio_device->put_char(std_devices->stdio_device,c);
}

int sl_puts(const char *astring)
{
	int i=0;
	while (*(astring+i) != '\0') 
	{
		sl_putchar(*astring+i);
		i++;
	}
	return i;
}

static void sl_printchar(char **str, int c)
{
	if (str) {
		**str = c;
		++(*str);
	}
	else sl_putchar(c);
}

#define PAD_RIGHT 1
#define PAD_ZERO 2

static int sl_prints(char **out, const char *string, int width, int pad)
{
	register int pc = 0, padchar = ' ';

	if (width > 0) {
		register int len = 0;
		register const char *ptr;
		for (ptr = string; *ptr; ++ptr) ++len;
		if (len >= width) width = 0;
		else width -= len;
		if (pad & PAD_ZERO) padchar = '0';
	}
	if (!(pad & PAD_RIGHT)) {
		for ( ; width > 0; --width) {
			sl_printchar (out, padchar);
			++pc;
		}
	}
	for ( ; *string ; ++string) {
		sl_printchar (out, *string);
		++pc;
	}
	for ( ; width > 0; --width) {
		sl_printchar (out, padchar);
		++pc;
	}

	return pc;
}

#define PRINT_BUF_LEN 12

static int sl_printi(char **out, int i, int b, int sg, int width, int pad, int letbase)
{
	char print_buf[PRINT_BUF_LEN];
	register char *s;
	register int t, neg = 0, pc = 0;
	register unsigned int u = i;

	if (i == 0) {
		print_buf[0] = '0';
		print_buf[1] = '\0';
		return sl_prints (out, print_buf, width, pad);
	}

	if (sg && b == 10 && i < 0) {
		neg = 1;
		u = -i;
	}

	s = print_buf + PRINT_BUF_LEN-1;
	*s = '\0';

	while (u) {
		t = u % b;
		if( t >= 10 )
			t += letbase - '0' - 10;
		*--s = t + '0';
		u /= b;
	}

	if (neg) {
		if( width && (pad & PAD_ZERO) ) {
			sl_printchar (out, '-');
			++pc;
			--width;
		}
		else {
			*--s = '-';
		}
	}

	return pc + sl_prints (out, s, width, pad);
}

static int sl_printl(char **out, long i, int b, int sg, int width, int pad, int letbase)
{
	char print_buf[PRINT_BUF_LEN];
	register char *s;
	register int neg = 0, pc = 0;
	long t;
	unsigned long u = i;

	if (i == 0) {
		print_buf[0] = '0';
		print_buf[1] = '\0';
		return sl_prints (out, print_buf, width, pad);
	}

	if (sg && b == 10 && i < 0) {
		neg = 1;
		u = -i;
	}

	s = print_buf + PRINT_BUF_LEN-1;
	*s = '\0';

	while (u) {
		t = u % b;
		if( t >= 10 )
			t += letbase - '0' - 10;
		*--s = t + '0';
		u /= b;
	}

	if (neg) {
		if( width && (pad & PAD_ZERO) ) {
			sl_printchar (out, '-');
			++pc;
			--width;
		}
		else {
			*--s = '-';
		}
	}

	return pc + sl_prints (out, s, width, pad);
}

static int sl_print(char **out, int *varg)
{
	register int width, pad;
	register int pc = 0;
	register char *format = (char *)(*varg++);
	register int lon=0;
	char scr[2];

	for (; *format != 0; ++format) {
		if (*format == '%') {
			++format;
			lon = width = pad = 0;
			if (*format == '\0') break;
			if (*format == '%') goto out;
			if (*format == '-') {
				++format;
				pad = PAD_RIGHT;
			}
			while (*format == '0') {
				++format;
				pad |= PAD_ZERO;
			}
			for ( ; *format >= '0' && *format <= '9'; ++format) {
				width *= 10;
				width += *format - '0';
			}
			if( *format == 's' ) {
				register char *s = *((char **)varg++);
				pc += sl_prints (out, s?s:"(null)", width, pad);
				continue;
			}
			if( *format == 'l' ) {
				format++;
				lon=1;
			}
			if( *format == 'd' ) {
				if (lon)
					pc += sl_printl (out, *((long*)varg++), 10, 1, width, pad, 'a');
				else
					pc += sl_printi (out, *varg++, 10, 1, width, pad, 'a');
				continue;
			}
			if( *format == 'x' ) {
				pc += sl_printi (out, *varg++, 16, 0, width, pad, 'a');
				continue;
			}
			if( *format == 'X' ) {
				pc += sl_printi (out, *varg++, 16, 0, width, pad, 'A');
				continue;
			}
			if( *format == 'u' ) {
				if (lon)
					pc += sl_printl (out, *((long*)varg++), 10, 0, width, pad, 'a');
				else
					pc += sl_printi (out, *varg++, 10, 0, width, pad, 'a');
				continue;
			}
			if( *format == 'c' ) {
				/* char are converted to int then pushed on the stack */
				scr[0] = *varg++;
				scr[1] = '\0';
				pc += sl_prints (out, scr, width, pad);
				continue;
			}
		}
		else {
		out:
			sl_printchar (out, *format);
			++pc;
		}
	}
	if (out) **out = '\0';
	return pc;
}

/* assuming sizeof(void *) == sizeof(int) */

int sl_printf(const char *format, ...)
{
	int *varg = (int *)(&format);
	return sl_print(0, varg);
}

int sl_sprintf(char *out, const char *format, ...)
{
	int *varg = (int *)(&format);
	return sl_print(&out, varg);
}

char *sl_strcpy(char *str1, const char *str2)
 {
 	register unsigned int k=0;
 	while ((*(char*)(str1+k) =*(char*)(str2+k))!='\0') 
 		k++;
 	return str1;
 }

void *sl_memcpy(void *str1, const void *str2, size_t n)
 {
 	register unsigned int k;
 	for (k=0;k<n;k++) 
 		*(char*)(str1 + k) = *(char*)(str2 + k);
 	return str1;
 }

size_t sl_strlen(const char *str)
 {
 	register unsigned int k=0;
 	while (*(char*)(str+k)!='\0') 
 		k++;
 	return (size_t) k;	
 }
 
int sl_strcmp(const char *str1, const char *str2)
 {
 	register unsigned int k=0;
 	while (*(str1+k)==*(str2+k))
 	{
 		if (*(str1+k)=='\0') return 0;
 		k++;
 	}
 	return (*(str1+k) - *(str2+k));
 }
 
char *sl_strcat(char *str1, const char *str2)
  {
  	register unsigned j=0;
  	register unsigned k=sl_strlen(str1);
  	while ( (*(str1+k+j)= *(str2+j)) != '\0')
  		j++; 
  	return str1;
  }

//atoi für unsigned ints 
int sl_atoi(char const* str)
{
	int result = 0;
	char c;
	while((c = *(str++) )) // for each non-NUL digit
	{
		if ((c-'0')>9) return 0; 
		result = result*10 + (c-'0');
	} 
	return result;
}

int sl_abs(int c)
{
	if (c<0) return (c*-1);
	return c;
}

static long seed;

long sl_rand (void)
{
	long a = 1664525;
	long c = 1013904223;
	seed = a*seed+c;
	return seed;
}

void sl_srand(long s)
{
	seed =s;
}
