/* Copyright (C) 2005, 2006, 2007, 2008 by Thomas Hillebrandt and Heiko Will

This file is part of the Micro-mesh SensorWeb Firmware.

Micro-Mesh is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3, or (at your option)
any later version.

Micro-Mesh is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with Micro-Mesh; see the file COPYING.  If not, write to
the Free Software Foundation, 59 Temple Place - Suite 330,
Boston, MA 02111-1307, USA.  */

#include "timer.h"
#include "helpers.h"
#include "driver_timer.h"
#include "driver_system.h"
#include <stdio.h>

#define MAX_TIMERS	(3)

typedef struct t {
	fp_timer fp;
	unsigned int ticks;
	uint16_t id;
} timer;

void process_timer(void);
volatile fp_timer fired_timers[FIRED_TIMERS_SIZE];

static timer registeredTimer[MAX_TIMERS];
static int activeTimer;
static uint16_t nextId;

void init_timer0(void)
{
  driver_timer_load(process_timer);
  int i=0;
  	while(i < MAX_TIMERS)
	{
		registeredTimer[i++].id = 0;
	}
	activeTimer = -1;
	nextId = 1;
	
	for (i = 0; i < FIRED_TIMERS_SIZE; i++)
	{
		fired_timers[i] = NULL;
	}
}

void process_timer(void)
{
	int i;
	mEventFlags.Bits.TIMER = true;
	for (i = 0; i < FIRED_TIMERS_SIZE; i++)
	{
		if (fired_timers[i] == NULL)
		{
			fired_timers[i] = registeredTimer[activeTimer].fp;
			break;
		}
	}
	delete_timer(registeredTimer[activeTimer].id);
}

void wait_ticks(unsigned int num)
{
	_wait(num);
}

int register_timer(fp_timer fp, unsigned int ticks)
{
	unsigned int tbrDump = get_timer_count();
	if (!ticks) return -1;
	
	int i = 0;
	while(i < MAX_TIMERS)
	{
		if (registeredTimer[i].id == 0) break;
		i++;
	}
	if (i == MAX_TIMERS)
	{
		return -1;
	}
	
	registeredTimer[i].fp = fp;
	registeredTimer[i].ticks = tbrDump + ticks;
	registeredTimer[i].id = nextId++;
	
	if (activeTimer >= 0)
	{
		if (registeredTimer[activeTimer].ticks > tbrDump)
		{
			if (registeredTimer[i].ticks > tbrDump)
			{
				if (registeredTimer[i].ticks < registeredTimer[activeTimer].ticks)
				{
					activeTimer = i;
				}
			}
		}
		else
		{
			if (registeredTimer[i].ticks > tbrDump)
			{
				activeTimer = i;
			}
			else
			{
				if (registeredTimer[i].ticks < registeredTimer[activeTimer].ticks)
				{
					activeTimer = i;
				}
			}
		}
	}
	else
	{
		activeTimer = i;
	}
	
	set_next_timer_value(registeredTimer[activeTimer].ticks);	
	
	system_state.TIMER_ACTIVE = true;
	return registeredTimer[i].id;
}

void delete_timer(int id)
{
	int i;
	unsigned int tbrDump = get_timer_count();
			
	if (registeredTimer[activeTimer].id == id) // timer to delete is active
	{
		registeredTimer[activeTimer].id = 0;
		int smallestLess = -1;
		int smallestGreater = -1;
		unsigned int minVal1 = (2^(sizeof(unsigned int)*8))-1;
		unsigned int minVal2 = (2^(sizeof(unsigned int)*8))-1;
		
		for (i = 0; i < MAX_TIMERS; i++)
		{
			if (registeredTimer[i].id != 0) 
			{
				if (registeredTimer[i].ticks > tbrDump)
				{
					if (registeredTimer[i].ticks < minVal1)
					{
						minVal1 = registeredTimer[i].ticks;
						smallestGreater = i;
					}
				}
				else
				{
					if (registeredTimer[i].ticks < minVal2)
					{
						minVal2 = registeredTimer[i].ticks;
						smallestLess = i;
					}
				}
			}
		}
		
				
		if (smallestGreater != -1)
		{
			activeTimer = smallestGreater;
			set_next_timer_value(registeredTimer[activeTimer].ticks);	
		}
		else if (smallestLess != -1)
		{
			activeTimer = smallestLess;
			set_next_timer_value(registeredTimer[activeTimer].ticks);	
		}
		else
		{
			// No timer available
			activeTimer = -1;
			system_state.TIMER_ACTIVE = false;
			disable_timer();
		}
	}
	else
	{
		int i = 0;
		while(i < MAX_TIMERS)  // search timer to delete
		{
			if (registeredTimer[i].id == id)
					registeredTimer[i].id = 0;
			i++;
		}
	}
}



