package carrera.data;

import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;

/**
 *
 * @author hillebra
 */
public class CarreraPlayer implements Comparable<CarreraPlayer>, java.io.Serializable {

    private String name;
    private boolean auto;
    private int currentLap;
    private boolean firstLapDecreased;
    private List<Long> lapTimes;
    private long overallTime = -1;
    private transient long currentLapStartTime;
    
    public static final int MAX_NAME_LENGTH = 18;
    public static final String AUTO_DEFAULT_NAME = "MSB430-HC";
    
    public CarreraPlayer(String name, int currentLap, boolean auto) {
        this.name = name;
        this.auto = auto;
        this.currentLap = currentLap;
        firstLapDecreased = false;
        lapTimes = new LinkedList<Long>();
    }
    
    public String getName() {
        return name;
    }
    
    public boolean isAuto() {
        return auto;
    }
    
    public boolean isFirstLapDecreased() {
        return firstLapDecreased;
    }
    
    public void setFirstLapDecreased(boolean b) {
        firstLapDecreased = b;
    }

    public int getCurrentLap() {
        return currentLap;
    }
    
    public void decreaseCurrentLap() {
        currentLap--;
    }

    public void setCurrentLap(int currentLap) {
        this.currentLap = currentLap;
    }

    public long getCurrentLapStartTime() {
        return currentLapStartTime;
    }

    public void setCurrentLapStartTime(long currentLapStartTime) {
        this.currentLapStartTime = currentLapStartTime;
    }

    public List<Long> getLapTimes() {
        return lapTimes;
    }
    
    public void addLapTime(long time) {
        synchronized (lapTimes) {
            lapTimes.add(time);
        }
    }
    
    public long getOverallTime() {
        if (overallTime != -1) return overallTime;
        overallTime = 0;
        Iterator<Long> iter = lapTimes.iterator();
        while (iter.hasNext()) {
            overallTime += iter.next();
        }
        return overallTime;
    }
    
    public boolean didFinish() {
        return currentLap == 0;
    }
    
    @Override
    public boolean equals(Object o) {
        if (o instanceof CarreraPlayer) {
            CarreraPlayer p = (CarreraPlayer) o;
            if (auto && p.isAuto()) {
                return true;
            }
        }
        return super.equals(o);
    }

    public int compareTo(CarreraPlayer o) {
        return (int) (getOverallTime() - o.getOverallTime());
    }
    
}
