package carrera.data.plot;

import org.jfree.data.xy.XYSeries;
import org.jfree.data.xy.XYSeriesCollection;

/**
 *
 * @author hillebra
 */
public class PlotData {

    /** Daten des Beschleunigungssensors */
    private XYSeriesCollection accSeries;
    private XYSeries acc_x;
    private XYSeries acc_x_raw;
    private XYSeries acc_y;
    private XYSeries acc_y_raw;
    private XYSeries acc_z;
    private XYSeries acc_z_raw;
    
    /** Daten für Kalibrierung */
    private int calibrationCount;
    private int averageAccX = 0;
    private int averageAccY = 0;
    private int averageAccZ = 0;
    private int averageAccRawX = 0;
    private int averageAccRawY = 0;
    private int averageAccRawZ = 0;
    
    private static final String ACC_X = "ACC_X";
    private static final String ACC_Y = "ACC_Y";
    private static final String ACC_Z = "ACC_Z";
    private static final String ACC_X_RAW = "ACC_X_RAW";
    private static final String ACC_Y_RAW = "ACC_Y_RAW";
    private static final String ACC_Z_RAW = "ACC_Z_RAW";
    
    /** Daten des Gyroskops */
    private XYSeriesCollection gyroSeries;
    private XYSeries gyro_x;
    private XYSeries gyro_x_raw;
    private XYSeries gyro_y;
    private XYSeries gyro_y_raw;
    private XYSeries gyro_z;
    private XYSeries gyro_z_raw;
    
    /** Daten für Kalibrierung */
    private int gyroCalibrationCount;
    private int averageGyroX = 0;
    private int averageGyroY = 0;
    private int averageGyroZ = 0;
    private int averageGyroRawX = 0;
    private int averageGyroRawY = 0;
    private int averageGyroRawZ = 0;
    
    private static final String GYRO_X = "GYRO_X";
    private static final String GYRO_Y = "GYRO_Y";
    private static final String GYRO_Z = "GYRO_Z";
    private static final String GYRO_X_RAW = "GYRO_X_RAW";
    private static final String GYRO_Y_RAW = "GYRO_Y_RAW";
    private static final String GYRO_Z_RAW = "GYRO_Z_RAW";
    
    private static final int MAX_SAMPLES = 1000;
    private static final int CALIBRATION_LIMIT = 500;
    
    public PlotData() {
        accSeries = new XYSeriesCollection();
        acc_x = new XYSeries(ACC_X);
        acc_x_raw = new XYSeries(ACC_X_RAW);
        acc_y = new XYSeries(ACC_Y);
        acc_y_raw = new XYSeries(ACC_Y_RAW);
        acc_z = new XYSeries(ACC_Z);
        acc_z_raw = new XYSeries(ACC_Z_RAW);
        acc_x.setMaximumItemCount(MAX_SAMPLES);
        acc_x_raw.setMaximumItemCount(MAX_SAMPLES);
        acc_y.setMaximumItemCount(MAX_SAMPLES);
        acc_y_raw.setMaximumItemCount(MAX_SAMPLES);
        acc_z.setMaximumItemCount(MAX_SAMPLES);
        acc_z_raw.setMaximumItemCount(MAX_SAMPLES);
        accSeries.addSeries(acc_x);
        accSeries.addSeries(acc_x_raw);
        accSeries.addSeries(acc_y);
        accSeries.addSeries(acc_y_raw);
        accSeries.addSeries(acc_z);
        accSeries.addSeries(acc_z_raw);
        calibrationCount = 0;
        averageAccX = 0;
        averageAccY = 0;
        averageAccZ = 0;
        averageAccRawX = 0;
        averageAccRawY = 0;
        averageAccRawZ = 0;
        
        gyroSeries = new XYSeriesCollection();
        gyro_x = new XYSeries(GYRO_X);
        gyro_x_raw = new XYSeries(GYRO_X_RAW);
        gyro_y = new XYSeries(GYRO_Y);
        gyro_y_raw = new XYSeries(GYRO_Y_RAW);
        gyro_z = new XYSeries(GYRO_Z);
        gyro_z_raw = new XYSeries(GYRO_Z_RAW);
        gyro_x.setMaximumItemCount(MAX_SAMPLES);
        gyro_x_raw.setMaximumItemCount(MAX_SAMPLES);
        gyro_y.setMaximumItemCount(MAX_SAMPLES);
        gyro_y_raw.setMaximumItemCount(MAX_SAMPLES);
        gyro_z.setMaximumItemCount(MAX_SAMPLES);
        gyro_z_raw.setMaximumItemCount(MAX_SAMPLES);
        gyroSeries.addSeries(gyro_x);
        gyroSeries.addSeries(gyro_x_raw);
        gyroSeries.addSeries(gyro_y);
        gyroSeries.addSeries(gyro_y_raw);
        gyroSeries.addSeries(gyro_z);
        gyroSeries.addSeries(gyro_z_raw);
        gyroCalibrationCount = 0;
        averageGyroX = 0;
        averageGyroY = 0;
        averageGyroZ = 0;
        averageGyroRawX = 0;
        averageGyroRawY = 0;
        averageGyroRawZ = 0;
    }

    public XYSeriesCollection getAccDataset() {
        return accSeries;
    }
    
    public XYSeriesCollection getGyroDataset() {
        return gyroSeries;
    }
    
    public void addAccData(int x_raw, int y_raw, int z_raw, int x, int y, int z) {
        if (calibrationCount > CALIBRATION_LIMIT) {
            final int fi_count = calibrationCount;
            final int fi_x =  x - averageAccX;
            final int fi_y =  y - averageAccY;
            final int fi_z =  z - averageAccZ;
            
            final int fi_raw_x = x_raw - averageAccRawX;
            final int fi_raw_y = y_raw - averageAccRawY;
            final int fi_raw_z = z_raw - averageAccRawZ;
            
            java.awt.EventQueue.invokeLater(new Runnable() {
                public void run() {
                    boolean notify = fi_count % 10 == 0;
                    if (acc_x != null) acc_x.add(fi_count, fi_x, notify);
                    if (acc_y != null) acc_y.add(fi_count, fi_y, notify);
                    if (acc_z != null) acc_z.add(fi_count, fi_z, notify);
                    if (acc_x_raw != null) acc_x_raw.add(fi_count, fi_raw_x,
                            notify);
                    if (acc_y_raw != null) acc_y_raw.add(fi_count, fi_raw_y,
                            notify);
                    if (acc_z_raw != null) acc_z_raw.add(fi_count, fi_raw_z,
                            notify);
                }
            });
        } else if (calibrationCount == CALIBRATION_LIMIT) {
            averageAccX /= CALIBRATION_LIMIT;
            averageAccY /= CALIBRATION_LIMIT;
            averageAccZ /= CALIBRATION_LIMIT;
            averageAccRawX /= CALIBRATION_LIMIT;
            averageAccRawY /= CALIBRATION_LIMIT;
            averageAccRawZ /= CALIBRATION_LIMIT;
        } else {
            averageAccX += x;
            averageAccY += y;
            averageAccZ += z;
            averageAccRawX += x_raw;
            averageAccRawY += y_raw;
            averageAccRawZ += z_raw;
        }
        calibrationCount++;
    }
    
    public void addGyroData(int x_raw, int y_raw, int z_raw, int x, int y, int z) {
        if (gyroCalibrationCount > CALIBRATION_LIMIT) {
            final int fi_count = gyroCalibrationCount;
            final int fi_x =  x - averageGyroX;
            final int fi_y =  y - averageGyroY;
            final int fi_z =  z - averageGyroZ;
            
            final int fi_raw_x = x_raw - averageGyroRawX;
            final int fi_raw_y = y_raw - averageGyroRawY;
            final int fi_raw_z = z_raw - averageGyroRawZ;
            
            java.awt.EventQueue.invokeLater(new Runnable() {
                public void run() {
                    boolean notify = fi_count % 10 == 0;
                    if (gyro_x != null) gyro_x.add(fi_count, fi_x, notify);
                    if (gyro_y != null) gyro_y.add(fi_count, fi_y, notify);
                    if (gyro_z != null) gyro_z.add(fi_count, fi_z, notify);
                    if (gyro_x_raw != null) gyro_x_raw.add(fi_count, fi_raw_x,
                            notify);
                    if (gyro_y_raw != null) gyro_y_raw.add(fi_count, fi_raw_y,
                            notify);
                    if (gyro_z_raw != null) gyro_z_raw.add(fi_count, fi_raw_z,
                            notify);
                }
            });
        } else if (gyroCalibrationCount == CALIBRATION_LIMIT) {
            averageGyroX /= CALIBRATION_LIMIT;
            averageGyroY /= CALIBRATION_LIMIT;
            averageGyroZ /= CALIBRATION_LIMIT;
            averageGyroRawX /= CALIBRATION_LIMIT;
            averageGyroRawY /= CALIBRATION_LIMIT;
            averageGyroRawZ /= CALIBRATION_LIMIT;
        } else {
            averageGyroX += x;
            averageGyroY += y;
            averageGyroZ += z;
            averageGyroRawX += x_raw;
            averageGyroRawY += y_raw;
            averageGyroRawZ += z_raw;
        }
        gyroCalibrationCount++;
    }
    
}
